@@ -45,16 +45,48 @@ pub fn dns_parse_header(i: &[u8]) -> IResult<&[u8], DNSHeader> {
     ))
 }
 
+// Set a maximum assembled hostname length of 1025, this value was
+// chosen as its what DNSMasq uses, a popular DNS server, even if most
+// tooling limits names to 256 chars without special options.
+static MAX_NAME_LEN: usize = 1025;
+
 /// Parse a DNS name.
 ///
+/// Names are parsed with the following restrictions:
+///
+/// - Only 255 segments will be processed, if more the parser may
+///   error out. This is also our safeguard against an infinite loop. If
+///   a pointer had been followed a truncated name will be
+///   returned. However if pointer has been processed we error out as we
+///   don't know where the next data point starts without more
+///   iterations.
+///
+/// - The maximum name parsed in representation format is MAX_NAME_LEN
+///   characters. Once larger, the truncated name will be returned with
+///   a flag specifying the name was truncated. Note that parsing
+///   continues if no pointer has been used as we still need to find the
+///   start of the next protocol unit.
+///
+/// As some error in parsing the name are recoverable, a DNSName
+/// object is returned with flags signifying a recoverable
+/// error. These errors include:
+///
+/// - infinite loop: as we know the end of the name in the input
+///   stream, we can return what we've parsed with the remain data.
+///
+/// - maximum number of segments/labels parsed
+///
+/// - truncation of name when too long
+///
 /// Parameters:
 ///   start: the start of the name
 ///   message: the complete message that start is a part of with the DNS header
-pub fn dns_parse_name<'b>(start: &'b [u8], message: &'b [u8]) -> IResult<&'b [u8], Vec<u8>> {
+pub fn dns_parse_name<'b>(start: &'b [u8], message: &'b [u8], parse_flags: &mut DNSNameFlags) -> IResult<&'b [u8], DNSName> {
     let mut pos = start;
     let mut pivot = start;
     let mut name: Vec<u8> = Vec::with_capacity(32);
     let mut count = 0;
+    let mut flags = DNSNameFlags::default();
 
     loop {
         if pos.is_empty() {
@@ -68,10 +100,12 @@ pub fn dns_parse_name<'b>(start: &'b [u8], message: &'b [u8]) -> IResult<&'b [u8
             break;
         } else if len & 0b1100_0000 == 0 {
             let (rem, label) = length_data(be_u8)(pos)?;
-            if !name.is_empty() {
-                name.push(b'.');
+            if !flags.contains(DNSNameFlags::TRUNCATED) {
+                if !name.is_empty() {
+                    name.push(b'.');
+                }
+                name.extend(label);
             }
-            name.extend(label);
             pos = rem;
         } else if len & 0b1100_0000 == 0b1100_0000 {
             let (rem, leader) = be_u16(pos)?;
@@ -79,6 +113,21 @@ pub fn dns_parse_name<'b>(start: &'b [u8], message: &'b [u8]) -> IResult<&'b [u8
             if offset > message.len() {
                 return Err(Err::Error(error_position!(pos, ErrorKind::OctDigit)));
             }
+
+            if &message[offset..] == pos {
+                // Self reference, immedate infinite loop.
+                flags.insert(DNSNameFlags::INFINITE_LOOP);
+
+                // If we have followed a pointer, we can just break as
+                // we've already found the end of the input. But if we
+                // have not followed a pointer yet return a parse
+                // error.
+                if pivot != start {
+                    break;
+                }
+                return Err(Err::Error(error_position!(pos, ErrorKind::OctDigit)));
+            }
+
             pos = &message[offset..];
             if pivot == start {
                 pivot = rem;
@@ -89,19 +138,45 @@ pub fn dns_parse_name<'b>(start: &'b [u8], message: &'b [u8]) -> IResult<&'b [u8
 
         // Return error if we've looped a certain number of times.
         count += 1;
+
         if count > 255 {
+            flags.insert(DNSNameFlags::LABEL_LIMIT);
+
+            // Our segment limit has been reached, if we have hit a
+            // pointer we can just return the truncated name. If we
+            // have not hit a pointer, we need to bail with an error.
+            if pivot != start {
+                flags.insert(DNSNameFlags::TRUNCATED);
+                break;
+            }
             return Err(Err::Error(error_position!(pos, ErrorKind::OctDigit)));
         }
+
+        if name.len() > MAX_NAME_LEN {
+            name.truncate(MAX_NAME_LEN);
+            flags.insert(DNSNameFlags::TRUNCATED);
+
+            // If we have pivoted due to a pointer we know where the
+            // end of the data is, so we can break early. Otherwise
+            // we'll keep parsing in hopes to find the end of the name
+            // so parsing can continue.
+            if pivot != start {
+                break;
+            }
+        }
     }
 
+    parse_flags.insert(flags);
+
     // If we followed a pointer we return the position after the first
     // pointer followed. Is there a better way to see if these slices
     // diverged from each other?  A straight up comparison would
     // actually check the contents.
-    if pivot.len() != start.len() {
-        return Ok((pivot, name));
+    if pivot != start {
+        Ok((pivot, DNSName { value: name, flags }))
+    } else {
+        Ok((pos, DNSName { value: name, flags }))
     }
-    return Ok((pos, name));
 }
 
 /// Parse answer entries.
@@ -115,21 +190,23 @@ pub fn dns_parse_name<'b>(start: &'b [u8], message: &'b [u8]) -> IResult<&'b [u8
 /// multi-string TXT entry as a single quote string, similar to the
 /// output of dig. Something to consider for a future version.
 fn dns_parse_answer<'a>(
-    slice: &'a [u8], message: &'a [u8], count: usize,
+    slice: &'a [u8], message: &'a [u8], count: usize, flags: &mut DNSNameFlags,
 ) -> IResult<&'a [u8], Vec<DNSAnswerEntry>> {
     let mut answers = Vec::new();
     let mut input = slice;
 
     struct Answer<'a> {
-        name: Vec<u8>,
+        name: DNSName,
         rrtype: u16,
         rrclass: u16,
         ttl: u32,
         data: &'a [u8],
     }
 
-    fn subparser<'a>(i: &'a [u8], message: &'a [u8]) -> IResult<&'a [u8], Answer<'a>> {
-        let (i, name) = dns_parse_name(i, message)?;
+    fn subparser<'a>(
+        i: &'a [u8], message: &'a [u8], flags: &mut DNSNameFlags,
+    ) -> IResult<&'a [u8], Answer<'a>> {
+        let (i, name) = dns_parse_name(i, message, flags)?;
         let (i, rrtype) = be_u16(i)?;
         let (i, rrclass) = be_u16(i)?;
         let (i, ttl) = be_u32(i)?;
@@ -145,7 +222,7 @@ fn dns_parse_answer<'a>(
     }
 
     for _ in 0..count {
-        match subparser(input, message) {
+        match subparser(input, message, flags) {
             Ok((rem, val)) => {
                 let n = match val.rrtype {
                     DNS_RECORD_TYPE_TXT => {
@@ -163,7 +240,7 @@ fn dns_parse_answer<'a>(
                     }
                 };
                 let result: IResult<&'a [u8], Vec<DNSRData>> =
-                    many_m_n(1, n, complete(|b| dns_parse_rdata(b, message, val.rrtype)))(val.data);
+                    many_m_n(1, n, complete(|b| dns_parse_rdata(b, message, val.rrtype, flags)))(val.data);
                 match result {
                     Ok((_, rdatas)) => {
                         for rdata in rdatas {
@@ -193,18 +270,19 @@ fn dns_parse_answer<'a>(
 
 pub fn dns_parse_response_body<'a>(
     i: &'a [u8], message: &'a [u8], header: DNSHeader,
-) -> IResult<&'a [u8], DNSResponse> {
-    let (i, queries) = count(|b| dns_parse_query(b, message), header.questions as usize)(i)?;
-    let (i, answers) = dns_parse_answer(i, message, header.answer_rr as usize)?;
-    let (i, authorities) = dns_parse_answer(i, message, header.authority_rr as usize)?;
+) -> IResult<&'a [u8], (DNSResponse, DNSNameFlags)> {
+    let mut flags = DNSNameFlags::default();
+    let (i, queries) = count(|b| dns_parse_query(b, message, &mut flags), header.questions as usize)(i)?;
+    let (i, answers) = dns_parse_answer(i, message, header.answer_rr as usize, &mut flags)?;
+    let (i, authorities) = dns_parse_answer(i, message, header.authority_rr as usize, &mut flags)?;
     Ok((
         i,
-        DNSResponse {
+        (DNSResponse {
             header,
             queries,
             answers,
             authorities,
-        },
+        }, flags),
     ))
 }
 
@@ -213,9 +291,9 @@ pub fn dns_parse_response_body<'a>(
 /// Arguments are suitable for using with call!:
 ///
 ///    call!(complete_dns_message_buffer)
-pub fn dns_parse_query<'a>(input: &'a [u8], message: &'a [u8]) -> IResult<&'a [u8], DNSQueryEntry> {
+pub fn dns_parse_query<'a>(input: &'a [u8], message: &'a [u8], flags: &mut DNSNameFlags) -> IResult<&'a [u8], DNSQueryEntry> {
     let i = input;
-    let (i, name) = dns_parse_name(i, message)?;
+    let (i, name) = dns_parse_name(i, message, flags)?;
     let (i, rrtype) = be_u16(i)?;
     let (i, rrclass) = be_u16(i)?;
     Ok((
@@ -236,22 +314,30 @@ fn dns_parse_rdata_aaaa(input: &[u8]) -> IResult<&[u8], DNSRData> {
     rest(input).map(|(input, data)| (input, DNSRData::AAAA(data.to_vec())))
 }
 
-fn dns_parse_rdata_cname<'a>(input: &'a [u8], message: &'a [u8]) -> IResult<&'a [u8], DNSRData> {
-    dns_parse_name(input, message).map(|(input, name)| (input, DNSRData::CNAME(name)))
+fn dns_parse_rdata_cname<'a>(
+    input: &'a [u8], message: &'a [u8], flags: &mut DNSNameFlags,
+) -> IResult<&'a [u8], DNSRData> {
+    dns_parse_name(input, message, flags).map(|(input, name)| (input, DNSRData::CNAME(name)))
 }
 
-fn dns_parse_rdata_ns<'a>(input: &'a [u8], message: &'a [u8]) -> IResult<&'a [u8], DNSRData> {
-    dns_parse_name(input, message).map(|(input, name)| (input, DNSRData::NS(name)))
+fn dns_parse_rdata_ns<'a>(
+    input: &'a [u8], message: &'a [u8], flags: &mut DNSNameFlags,
+) -> IResult<&'a [u8], DNSRData> {
+    dns_parse_name(input, message, flags).map(|(input, name)| (input, DNSRData::NS(name)))
 }
 
-fn dns_parse_rdata_ptr<'a>(input: &'a [u8], message: &'a [u8]) -> IResult<&'a [u8], DNSRData> {
-    dns_parse_name(input, message).map(|(input, name)| (input, DNSRData::PTR(name)))
+fn dns_parse_rdata_ptr<'a>(
+    input: &'a [u8], message: &'a [u8], flags: &mut DNSNameFlags,
+) -> IResult<&'a [u8], DNSRData> {
+    dns_parse_name(input, message, flags).map(|(input, name)| (input, DNSRData::PTR(name)))
 }
 
-fn dns_parse_rdata_soa<'a>(input: &'a [u8], message: &'a [u8]) -> IResult<&'a [u8], DNSRData> {
+fn dns_parse_rdata_soa<'a>(
+    input: &'a [u8], message: &'a [u8], flags: &mut DNSNameFlags,
+) -> IResult<&'a [u8], DNSRData> {
     let i = input;
-    let (i, mname) = dns_parse_name(i, message)?;
-    let (i, rname) = dns_parse_name(i, message)?;
+    let (i, mname) = dns_parse_name(i, message, flags)?;
+    let (i, rname) = dns_parse_name(i, message, flags)?;
     let (i, serial) = be_u32(i)?;
     let (i, refresh) = be_u32(i)?;
     let (i, retry) = be_u32(i)?;
@@ -271,20 +357,24 @@ fn dns_parse_rdata_soa<'a>(input: &'a [u8], message: &'a [u8]) -> IResult<&'a [u
     ))
 }
 
-fn dns_parse_rdata_mx<'a>(input: &'a [u8], message: &'a [u8]) -> IResult<&'a [u8], DNSRData> {
+fn dns_parse_rdata_mx<'a>(
+    input: &'a [u8], message: &'a [u8], flags: &mut DNSNameFlags,
+) -> IResult<&'a [u8], DNSRData> {
     // For MX we skip over the preference field before
     // parsing out the name.
     let (i, _) = be_u16(input)?;
-    let (i, name) = dns_parse_name(i, message)?;
+    let (i, name) = dns_parse_name(i, message, flags)?;
     Ok((i, DNSRData::MX(name)))
 }
 
-fn dns_parse_rdata_srv<'a>(input: &'a [u8], message: &'a [u8]) -> IResult<&'a [u8], DNSRData> {
+fn dns_parse_rdata_srv<'a>(
+    input: &'a [u8], message: &'a [u8], flags: &mut DNSNameFlags,
+) -> IResult<&'a [u8], DNSRData> {
     let i = input;
     let (i, priority) = be_u16(i)?;
     let (i, weight) = be_u16(i)?;
     let (i, port) = be_u16(i)?;
-    let (i, target) = dns_parse_name(i, message)?;
+    let (i, target) = dns_parse_name(i, message, flags)?;
     Ok((
         i,
         DNSRData::SRV(DNSRDataSRV {
@@ -325,26 +415,26 @@ fn dns_parse_rdata_unknown(input: &[u8]) -> IResult<&[u8], DNSRData> {
 }
 
 pub fn dns_parse_rdata<'a>(
-    input: &'a [u8], message: &'a [u8], rrtype: u16,
+    input: &'a [u8], message: &'a [u8], rrtype: u16, flags: &mut DNSNameFlags
 ) -> IResult<&'a [u8], DNSRData> {
     match rrtype {
         DNS_RECORD_TYPE_A => dns_parse_rdata_a(input),
         DNS_RECORD_TYPE_AAAA => dns_parse_rdata_aaaa(input),
-        DNS_RECORD_TYPE_CNAME => dns_parse_rdata_cname(input, message),
-        DNS_RECORD_TYPE_PTR => dns_parse_rdata_ptr(input, message),
-        DNS_RECORD_TYPE_SOA => dns_parse_rdata_soa(input, message),
-        DNS_RECORD_TYPE_MX => dns_parse_rdata_mx(input, message),
-        DNS_RECORD_TYPE_NS => dns_parse_rdata_ns(input, message),
+        DNS_RECORD_TYPE_CNAME => dns_parse_rdata_cname(input, message, flags),
+        DNS_RECORD_TYPE_PTR => dns_parse_rdata_ptr(input, message, flags),
+        DNS_RECORD_TYPE_SOA => dns_parse_rdata_soa(input, message, flags),
+        DNS_RECORD_TYPE_MX => dns_parse_rdata_mx(input, message, flags),
+        DNS_RECORD_TYPE_NS => dns_parse_rdata_ns(input, message, flags),
         DNS_RECORD_TYPE_TXT => dns_parse_rdata_txt(input),
         DNS_RECORD_TYPE_NULL => dns_parse_rdata_null(input),
         DNS_RECORD_TYPE_SSHFP => dns_parse_rdata_sshfp(input),
-        DNS_RECORD_TYPE_SRV => dns_parse_rdata_srv(input, message),
+        DNS_RECORD_TYPE_SRV => dns_parse_rdata_srv(input, message, flags),
         _ => dns_parse_rdata_unknown(input),
     }
 }
 
 /// Parse a DNS request.
-pub fn dns_parse_request(input: &[u8]) -> IResult<&[u8], DNSRequest> {
+pub fn dns_parse_request(input: &[u8]) -> IResult<&[u8], (DNSRequest, DNSNameFlags)> {
     let i = input;
     let (i, header) = dns_parse_header(i)?;
     dns_parse_request_body(i, input, header)
@@ -352,10 +442,11 @@ pub fn dns_parse_request(input: &[u8]) -> IResult<&[u8], DNSRequest> {
 
 pub fn dns_parse_request_body<'a>(
     input: &'a [u8], message: &'a [u8], header: DNSHeader,
-) -> IResult<&'a [u8], DNSRequest> {
+) -> IResult<&'a [u8], (DNSRequest, DNSNameFlags)> {
+    let mut flags = DNSNameFlags::default();
     let i = input;
-    let (i, queries) = count(|b| dns_parse_query(b, message), header.questions as usize)(i)?;
-    Ok((i, DNSRequest { header, queries }))
+    let (i, queries) = count(|b| dns_parse_query(b, message, &mut flags), header.questions as usize)(i)?;
+    Ok((i, (DNSRequest { header, queries }, flags)))
 }
 
 #[cfg(test)]
@@ -374,8 +465,9 @@ mod tests {
             0x03, 0x63, 0x6f, 0x6d, 0x00, 0x00, 0x01, 0x00, /* .com.... */
         ];
         let expected_remainder: &[u8] = &[0x00, 0x01, 0x00];
-        let (remainder, name) = dns_parse_name(buf, buf).unwrap();
-        assert_eq!("client-cf.dropbox.com".as_bytes(), &name[..]);
+        let mut flags = DNSNameFlags::default();
+        let (remainder, name) = dns_parse_name(buf, buf, &mut flags).unwrap();
+        assert_eq!("client-cf.dropbox.com".as_bytes(), &name.value[..]);
         assert_eq!(remainder, expected_remainder);
     }
 
@@ -408,37 +500,65 @@ mod tests {
 
         // The name at offset 54 is the complete name.
         let start1 = &buf[54..];
-        let res1 = dns_parse_name(start1, message);
+        let mut flags = DNSNameFlags::default();
+        let res1 = dns_parse_name(start1, message, &mut flags);
         assert_eq!(
             res1,
-            Ok((&start1[22..], "www.suricata-ids.org".as_bytes().to_vec()))
+            Ok((
+                &start1[22..],
+                DNSName {
+                    value: "www.suricata-ids.org".as_bytes().to_vec(),
+                    flags: DNSNameFlags::default(),
+                }
+            ))
         );
 
         // The second name starts at offset 80, but is just a pointer
         // to the first.
         let start2 = &buf[80..];
-        let res2 = dns_parse_name(start2, message);
+        let mut flags = DNSNameFlags::default();
+        let res2 = dns_parse_name(start2, message, &mut flags);
         assert_eq!(
             res2,
-            Ok((&start2[2..], "www.suricata-ids.org".as_bytes().to_vec()))
+            Ok((
+                &start2[2..],
+                DNSName {
+                    value: "www.suricata-ids.org".as_bytes().to_vec(),
+                    flags: DNSNameFlags::default()
+                }
+            ))
         );
 
         // The third name starts at offset 94, but is a pointer to a
         // portion of the first.
         let start3 = &buf[94..];
-        let res3 = dns_parse_name(start3, message);
+        let mut flags = DNSNameFlags::default();
+        let res3 = dns_parse_name(start3, message, &mut flags);
         assert_eq!(
             res3,
-            Ok((&start3[2..], "suricata-ids.org".as_bytes().to_vec()))
+            Ok((
+                &start3[2..],
+                DNSName {
+                    value: "suricata-ids.org".as_bytes().to_vec(),
+                    flags: DNSNameFlags::default()
+                }
+            ))
         );
 
         // The fourth name starts at offset 110, but is a pointer to a
         // portion of the first.
         let start4 = &buf[110..];
-        let res4 = dns_parse_name(start4, message);
+        let mut flags = DNSNameFlags::default();
+        let res4 = dns_parse_name(start4, message, &mut flags);
         assert_eq!(
             res4,
-            Ok((&start4[2..], "suricata-ids.org".as_bytes().to_vec()))
+            Ok((
+                &start4[2..],
+                DNSName {
+                    value: "suricata-ids.org".as_bytes().to_vec(),
+                    flags: DNSNameFlags::default()
+                }
+            ))
         );
     }
 
@@ -470,10 +590,17 @@ mod tests {
         // packet).
         let start: &[u8] = &buf[100..];
 
-        let res = dns_parse_name(start, message);
+        let mut flags = DNSNameFlags::default();
+        let res = dns_parse_name(start, message, &mut flags);
         assert_eq!(
             res,
-            Ok((&start[2..], "block.g1.dropbox.com".as_bytes().to_vec()))
+            Ok((
+                &start[2..],
+                DNSName {
+                    value: "block.g1.dropbox.com".as_bytes().to_vec(),
+                    flags: DNSNameFlags::default()
+                }
+            ))
         );
     }
 
@@ -492,7 +619,7 @@ mod tests {
 
         let res = dns_parse_request(pkt);
         match res {
-            Ok((rem, request)) => {
+            Ok((rem, (request, _flags))) => {
                 // For now we have some remainder data as there is an
                 // additional record type we don't parse yet.
                 assert!(!rem.is_empty());
@@ -512,7 +639,7 @@ mod tests {
                 assert_eq!(request.queries.len(), 1);
 
                 let query = &request.queries[0];
-                assert_eq!(query.name, "www.suricata-ids.org".as_bytes().to_vec());
+                assert_eq!(query.name.value, "www.suricata-ids.org".as_bytes().to_vec());
                 assert_eq!(query.rrtype, 1);
                 assert_eq!(query.rrclass, 1);
             }
@@ -523,7 +650,7 @@ mod tests {
     }
 
     /// Parse a DNS response.
-    fn dns_parse_response(message: &[u8]) -> IResult<&[u8], DNSResponse> {
+    fn dns_parse_response(message: &[u8]) -> IResult<&[u8], (DNSResponse, DNSNameFlags)> {
         let i = message;
         let (i, header) = dns_parse_header(i)?;
         dns_parse_response_body(i, message, header)
@@ -550,7 +677,7 @@ mod tests {
 
         let res = dns_parse_response(pkt);
         match res {
-            Ok((rem, response)) => {
+            Ok((rem, (response, _flags))) => {
                 // The response should be full parsed.
                 assert_eq!(rem.len(), 0);
 
@@ -569,20 +696,26 @@ mod tests {
                 assert_eq!(response.answers.len(), 3);
 
                 let answer1 = &response.answers[0];
-                assert_eq!(answer1.name, "www.suricata-ids.org".as_bytes().to_vec());
+                assert_eq!(answer1.name.value, "www.suricata-ids.org".as_bytes().to_vec());
                 assert_eq!(answer1.rrtype, 5);
                 assert_eq!(answer1.rrclass, 1);
                 assert_eq!(answer1.ttl, 3544);
                 assert_eq!(
                     answer1.data,
-                    DNSRData::CNAME("suricata-ids.org".as_bytes().to_vec())
+                    DNSRData::CNAME(DNSName {
+                        value: "suricata-ids.org".as_bytes().to_vec(),
+                        flags: Default::default(),
+                    })
                 );
 
                 let answer2 = &response.answers[1];
                 assert_eq!(
                     answer2,
                     &DNSAnswerEntry {
-                        name: "suricata-ids.org".as_bytes().to_vec(),
+                        name: DNSName {
+                            value: "suricata-ids.org".as_bytes().to_vec(),
+                            flags: Default::default(),
+                        },
                         rrtype: 1,
                         rrclass: 1,
                         ttl: 244,
@@ -594,7 +727,10 @@ mod tests {
                 assert_eq!(
                     answer3,
                     &DNSAnswerEntry {
-                        name: "suricata-ids.org".as_bytes().to_vec(),
+                        name: DNSName {
+                            value: "suricata-ids.org".as_bytes().to_vec(),
+                            flags: Default::default(),
+                        },
                         rrtype: 1,
                         rrclass: 1,
                         ttl: 244,
@@ -633,7 +769,7 @@ mod tests {
 
         let res = dns_parse_response(pkt);
         match res {
-            Ok((rem, response)) => {
+            Ok((rem, (response, _flags))) => {
                 // For now we have some remainder data as there is an
                 // additional record type we don't parse yet.
                 assert!(!rem.is_empty());
@@ -653,15 +789,21 @@ mod tests {
                 assert_eq!(response.authorities.len(), 1);
 
                 let authority = &response.authorities[0];
-                assert_eq!(authority.name, "oisf.net".as_bytes().to_vec());
+                assert_eq!(authority.name.value, "oisf.net".as_bytes().to_vec());
                 assert_eq!(authority.rrtype, 6);
                 assert_eq!(authority.rrclass, 1);
                 assert_eq!(authority.ttl, 899);
                 assert_eq!(
                     authority.data,
                     DNSRData::SOA(DNSRDataSOA {
-                        mname: "ns-110.awsdns-13.com".as_bytes().to_vec(),
-                        rname: "awsdns-hostmaster.amazon.com".as_bytes().to_vec(),
+                        mname: DNSName {
+                            value: "ns-110.awsdns-13.com".as_bytes().to_vec(),
+                            flags: DNSNameFlags::default()
+                        },
+                        rname: DNSName {
+                            value: "awsdns-hostmaster.amazon.com".as_bytes().to_vec(),
+                            flags: DNSNameFlags::default()
+                        },
                         serial: 1,
                         refresh: 7200,
                         retry: 900,
@@ -694,7 +836,7 @@ mod tests {
 
         let res = dns_parse_response(pkt);
         match res {
-            Ok((rem, response)) => {
+            Ok((rem, (response, _flags))) => {
                 // The response should be fully parsed.
                 assert_eq!(rem.len(), 0);
 
@@ -712,14 +854,14 @@ mod tests {
 
                 assert_eq!(response.queries.len(), 1);
                 let query = &response.queries[0];
-                assert_eq!(query.name, "vaaaakardli.pirate.sea".as_bytes().to_vec());
+                assert_eq!(query.name.value, "vaaaakardli.pirate.sea".as_bytes().to_vec());
                 assert_eq!(query.rrtype, DNS_RECORD_TYPE_NULL);
                 assert_eq!(query.rrclass, 1);
 
                 assert_eq!(response.answers.len(), 1);
 
                 let answer = &response.answers[0];
-                assert_eq!(answer.name, "vaaaakardli.pirate.sea".as_bytes().to_vec());
+                assert_eq!(answer.name.value, "vaaaakardli.pirate.sea".as_bytes().to_vec());
                 assert_eq!(answer.rrtype, DNS_RECORD_TYPE_NULL);
                 assert_eq!(answer.rrclass, 1);
                 assert_eq!(answer.ttl, 0);
@@ -806,7 +948,7 @@ mod tests {
 
         let res = dns_parse_response(pkt);
         match res {
-            Ok((rem, response)) => {
+            Ok((rem, (response, _flags))) => {
                 // The data should be fully parsed.
                 assert_eq!(rem.len(), 0);
 
@@ -819,7 +961,7 @@ mod tests {
                         assert_eq!(srv.weight, 1);
                         assert_eq!(srv.port, 5060);
                         assert_eq!(
-                            srv.target,
+                            srv.target.value,
                             "sip-anycast-2.voice.google.com".as_bytes().to_vec()
                         );
                     }
@@ -834,7 +976,7 @@ mod tests {
                         assert_eq!(srv.weight, 1);
                         assert_eq!(srv.port, 5060);
                         assert_eq!(
-                            srv.target,
+                            srv.target.value,
                             "sip-anycast-1.voice.google.com".as_bytes().to_vec()
                         );
                     }
@@ -848,4 +990,69 @@ mod tests {
             }
         }
     }
+
+    #[test]
+    fn test_dns_parse_name_truncated() {
+        // Generate a non-compressed hostname over our maximum of 1024.
+        let mut buf: Vec<u8> = vec![];
+        for _ in 0..17 {
+            buf.push(0b0011_1111);
+            for _ in 0..63 {
+                buf.push(b'a');
+            }
+        }
+
+        let mut flags = DNSNameFlags::default();
+        let (rem, name) = dns_parse_name(&buf, &buf, &mut flags).unwrap();
+        assert_eq!(name.value.len(), MAX_NAME_LEN);
+        assert!(name.flags.contains(DNSNameFlags::TRUNCATED));
+        assert!(rem.is_empty());
+    }
+
+    #[test]
+    fn test_dns_parse_name_truncated_max_segments_no_pointer() {
+        let mut buf: Vec<u8> = vec![];
+        for _ in 0..256 {
+            buf.push(0b0000_0001);
+            buf.push(b'a');
+        }
+
+        // This should fail as we've hit the segment limit without a
+        // pointer, we'd need to keep parsing more segments to figure
+        // out where the next data point lies.
+        let mut flags = DNSNameFlags::default();
+        assert!(dns_parse_name(&buf, &buf, &mut flags).is_err());
+    }
+
+    #[test]
+    fn test_dns_parse_name_truncated_max_segments_with_pointer() {
+        let mut buf: Vec<u8> = vec![];
+
+        // "a" at the beginning of the buffer.
+        buf.push(0b0000_0001);
+        buf.push(b'a');
+
+        // Followed by a pointer back to the beginning.
+        buf.push(0b1100_0000);
+        buf.push(0b0000_0000);
+
+        // The start of the name, which is pointer to the beginning of
+        // the buffer.
+        buf.push(0b1100_0000);
+        buf.push(0b000_0000);
+
+        let mut flags = DNSNameFlags::default();
+        let (_rem, name) = dns_parse_name(&buf[4..], &buf, &mut flags).unwrap();
+        assert_eq!(name.value.len(), 255);
+        assert!(name.flags.contains(DNSNameFlags::TRUNCATED));
+    }
+
+    #[test]
+    fn test_dns_parse_name_self_reference() {
+        let mut buf = vec![];
+        buf.push(0b1100_0000);
+        buf.push(0b0000_0000);
+        let mut flags = DNSNameFlags::default();
+        assert!(dns_parse_name(&buf, &buf, &mut flags).is_err());
+    }
 }
