@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Open Information Security Foundation
+/* Copyright (C) 2019-2022 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -19,12 +19,11 @@
 
 //! RDP application layer
 
-use crate::applayer::*;
-use crate::core::{self, AppProto, DetectEngineState, Flow, ALPROTO_UNKNOWN, IPPROTO_TCP};
+use crate::applayer::{self, *};
+use crate::core::{AppProto, Flow, ALPROTO_UNKNOWN, IPPROTO_TCP};
 use crate::rdp::parser::*;
-use nom;
+use nom7::Err;
 use std;
-use std::mem::transmute;
 use std::collections::VecDeque;
 use tls_parser::{parse_tls_plaintext, TlsMessage, TlsMessageHandshake, TlsRecordType};
 
@@ -34,12 +33,12 @@ static mut ALPROTO_RDP: AppProto = ALPROTO_UNKNOWN;
 // transactions
 //
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Eq)]
 pub struct CertificateBlob {
     pub data: Vec<u8>,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Eq)]
 pub enum RdpTransactionItem {
     X224ConnectionRequest(X224ConnectionRequest),
     X224ConnectionConfirm(X224ConnectionConfirm),
@@ -48,46 +47,38 @@ pub enum RdpTransactionItem {
     TlsCertificateChain(Vec<CertificateBlob>),
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Eq)]
 pub struct RdpTransaction {
     pub id: u64,
     pub item: RdpTransactionItem,
     // managed by macros `export_tx_get_detect_state!` and `export_tx_set_detect_state!`
-    de_state: Option<*mut DetectEngineState>,
     tx_data: AppLayerTxData,
 }
 
+impl Transaction for RdpTransaction {
+    fn id(&self) -> u64 {
+        self.id
+    }
+}
+
 impl RdpTransaction {
     fn new(id: u64, item: RdpTransactionItem) -> Self {
         Self {
             id,
             item,
-            de_state: None,
             tx_data: AppLayerTxData::new(),
         }
     }
-
-    fn free(&mut self) {
-        if let Some(de_state) = self.de_state {
-            core::sc_detect_engine_state_free(de_state);
-        }
-    }
-}
-
-impl Drop for RdpTransaction {
-    fn drop(&mut self) {
-        self.free();
-    }
 }
 
 #[no_mangle]
-pub extern "C" fn rs_rdp_state_get_tx(
+pub unsafe extern "C" fn rs_rdp_state_get_tx(
     state: *mut std::os::raw::c_void, tx_id: u64,
 ) -> *mut std::os::raw::c_void {
     let state = cast_pointer!(state, RdpState);
     match state.get_tx(tx_id) {
         Some(tx) => {
-            return unsafe { transmute(tx) };
+            return tx as *const _ as *mut _;
         }
         None => {
             return std::ptr::null_mut();
@@ -96,17 +87,11 @@ pub extern "C" fn rs_rdp_state_get_tx(
 }
 
 #[no_mangle]
-pub extern "C" fn rs_rdp_state_get_tx_count(state: *mut std::os::raw::c_void) -> u64 {
+pub unsafe extern "C" fn rs_rdp_state_get_tx_count(state: *mut std::os::raw::c_void) -> u64 {
     let state = cast_pointer!(state, RdpState);
     return state.next_id;
 }
 
-#[no_mangle]
-pub extern "C" fn rs_rdp_tx_get_progress_complete(_direction: u8) -> std::os::raw::c_int {
-    // a parser can implement a multi-step tx completion by using an arbitrary `n`
-    return 1;
-}
-
 #[no_mangle]
 pub extern "C" fn rs_rdp_tx_get_progress(
     _tx: *mut std::os::raw::c_void, _direction: u8,
@@ -120,17 +105,29 @@ pub extern "C" fn rs_rdp_tx_get_progress(
 // state
 //
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Eq)]
 pub struct RdpState {
+    state_data: AppLayerStateData,
     next_id: u64,
     transactions: VecDeque<RdpTransaction>,
     tls_parsing: bool,
     bypass_parsing: bool,
 }
 
+impl State<RdpTransaction> for RdpState {
+    fn get_transaction_count(&self) -> usize {
+        self.transactions.len()
+    }
+
+    fn get_transaction_by_index(&self, index: usize) -> Option<&RdpTransaction> {
+        self.transactions.get(index)
+    }
+}
+
 impl RdpState {
     fn new() -> Self {
         Self {
+            state_data: AppLayerStateData::new(),
             next_id: 0,
             transactions: VecDeque::new(),
             tls_parsing: false,
@@ -156,17 +153,12 @@ impl RdpState {
     }
 
     fn get_tx(&self, tx_id: u64) -> Option<&RdpTransaction> {
-        for tx in &self.transactions {
-            if tx.id == tx_id {
-                return Some(tx);
-            }
-        }
-        return None;
+        self.transactions.iter().find(|&tx| tx.id == tx_id)
     }
 
     fn new_tx(&mut self, item: RdpTransactionItem) -> RdpTransaction {
-        let tx = RdpTransaction::new(self.next_id, item);
         self.next_id += 1;
+        let tx = RdpTransaction::new(self.next_id, item);
         return tx;
     }
 
@@ -179,17 +171,17 @@ impl RdpState {
         let mut available = input;
 
         loop {
-            if available.len() == 0 {
+            if available.is_empty() {
                 return AppLayerResult::ok();
             }
             if self.tls_parsing {
-                match parse_tls_plaintext(&available) {
+                match parse_tls_plaintext(available) {
                     Ok((remainder, _tls)) => {
-                        // bytes available for futher parsing are what remain
+                        // bytes available for further parsing are what remain
                         available = remainder;
                     }
 
-                    Err(nom::Err::Incomplete(_)) => {
+                    Err(Err::Incomplete(_)) => {
                         // nom need not compatible with applayer need, request one more byte
                         return AppLayerResult::incomplete(
                             (input.len() - available.len()) as u32,
@@ -197,16 +189,16 @@ impl RdpState {
                         );
                     }
 
-                    Err(nom::Err::Failure(_)) | Err(nom::Err::Error(_)) => {
+                    Err(Err::Failure(_)) | Err(Err::Error(_)) => {
                         return AppLayerResult::err();
                     }
                 }
             } else {
                 // every message should be encapsulated within a T.123 tpkt
-                match parse_t123_tpkt(&available) {
+                match parse_t123_tpkt(available) {
                     // success
                     Ok((remainder, t123)) => {
-                        // bytes available for futher parsing are what remain
+                        // bytes available for further parsing are what remain
                         available = remainder;
                         // evaluate message within the tpkt
                         match t123.child {
@@ -219,6 +211,7 @@ impl RdpState {
 
                             // X.223 data packet, evaluate what it encapsulates
                             T123TpktChild::Data(x223) => {
+                                #[allow(clippy::single_match)]
                                 match x223.child {
                                     X223DataChild::McsConnectRequest(mcs) => {
                                         let tx =
@@ -235,7 +228,7 @@ impl RdpState {
                         }
                     }
 
-                    Err(nom::Err::Incomplete(_)) => {
+                    Err(Err::Incomplete(_)) => {
                         // nom need not compatible with applayer need, request one more byte
                         return AppLayerResult::incomplete(
                             (input.len() - available.len()) as u32,
@@ -243,7 +236,7 @@ impl RdpState {
                         );
                     }
 
-                    Err(nom::Err::Failure(_)) | Err(nom::Err::Error(_)) => {
+                    Err(Err::Failure(_)) | Err(Err::Error(_)) => {
                         if probe_tls_handshake(available) {
                             self.tls_parsing = true;
                             let r = self.parse_ts(available);
@@ -272,15 +265,16 @@ impl RdpState {
         let mut available = input;
 
         loop {
-            if available.len() == 0 {
+            if available.is_empty() {
                 return AppLayerResult::ok();
             }
             if self.tls_parsing {
-                match parse_tls_plaintext(&available) {
+                match parse_tls_plaintext(available) {
                     Ok((remainder, tls)) => {
-                        // bytes available for futher parsing are what remain
+                        // bytes available for further parsing are what remain
                         available = remainder;
                         for message in &tls.msg {
+                            #[allow(clippy::single_match)]
                             match message {
                                 TlsMessage::Handshake(TlsMessageHandshake::Certificate(
                                     contents,
@@ -301,7 +295,7 @@ impl RdpState {
                         }
                     }
 
-                    Err(nom::Err::Incomplete(_)) => {
+                    Err(Err::Incomplete(_)) => {
                         // nom need not compatible with applayer need, request one more byte
                         return AppLayerResult::incomplete(
                             (input.len() - available.len()) as u32,
@@ -309,16 +303,16 @@ impl RdpState {
                         );
                     }
 
-                    Err(nom::Err::Failure(_)) | Err(nom::Err::Error(_)) => {
+                    Err(Err::Failure(_)) | Err(Err::Error(_)) => {
                         return AppLayerResult::err();
                     }
                 }
             } else {
                 // every message should be encapsulated within a T.123 tpkt
-                match parse_t123_tpkt(&available) {
+                match parse_t123_tpkt(available) {
                     // success
                     Ok((remainder, t123)) => {
-                        // bytes available for futher parsing are what remain
+                        // bytes available for further parsing are what remain
                         available = remainder;
                         // evaluate message within the tpkt
                         match t123.child {
@@ -331,6 +325,7 @@ impl RdpState {
 
                             // X.223 data packet, evaluate what it encapsulates
                             T123TpktChild::Data(x223) => {
+                                #[allow(clippy::single_match)]
                                 match x223.child {
                                     X223DataChild::McsConnectResponse(mcs) => {
                                         let tx = self
@@ -350,7 +345,7 @@ impl RdpState {
                         }
                     }
 
-                    Err(nom::Err::Incomplete(_)) => {
+                    Err(Err::Incomplete(_)) => {
                         // nom need not compatible with applayer need, request one more byte
                         return AppLayerResult::incomplete(
                             (input.len() - available.len()) as u32,
@@ -358,7 +353,7 @@ impl RdpState {
                         );
                     }
 
-                    Err(nom::Err::Failure(_)) | Err(nom::Err::Error(_)) => {
+                    Err(Err::Failure(_)) | Err(Err::Error(_)) => {
                         if probe_tls_handshake(available) {
                             self.tls_parsing = true;
                             let r = self.parse_tc(available);
@@ -383,42 +378,35 @@ impl RdpState {
 pub extern "C" fn rs_rdp_state_new(_orig_state: *mut std::os::raw::c_void, _orig_proto: AppProto) -> *mut std::os::raw::c_void {
     let state = RdpState::new();
     let boxed = Box::new(state);
-    return unsafe { std::mem::transmute(boxed) };
+    return Box::into_raw(boxed) as *mut _;
 }
 
 #[no_mangle]
 pub extern "C" fn rs_rdp_state_free(state: *mut std::os::raw::c_void) {
-    let _drop: Box<RdpState> = unsafe { std::mem::transmute(state) };
+    std::mem::drop(unsafe { Box::from_raw(state as *mut RdpState) });
 }
 
 #[no_mangle]
-pub extern "C" fn rs_rdp_state_tx_free(state: *mut std::os::raw::c_void, tx_id: u64) {
+pub unsafe extern "C" fn rs_rdp_state_tx_free(state: *mut std::os::raw::c_void, tx_id: u64) {
     let state = cast_pointer!(state, RdpState);
     state.free_tx(tx_id);
 }
 
-//
-// detection state
-//
-
-export_tx_get_detect_state!(rs_rdp_tx_get_detect_state, RdpTransaction);
-export_tx_set_detect_state!(rs_rdp_tx_set_detect_state, RdpTransaction);
-
 //
 // probe
 //
 
 /// probe for T.123 type identifier, as each message is encapsulated in T.123
 fn probe_rdp(input: &[u8]) -> bool {
-    input.len() > 0 && input[0] == TpktVersion::T123 as u8
+    !input.is_empty() && input[0] == TpktVersion::T123 as u8
 }
 
 /// probe for T.123 message, whether to client or to server
 #[no_mangle]
-pub extern "C" fn rs_rdp_probe_ts_tc(
+pub unsafe extern "C" fn rs_rdp_probe_ts_tc(
     _flow: *const Flow, _direction: u8, input: *const u8, input_len: u32, _rdir: *mut u8,
 ) -> AppProto {
-    if input != std::ptr::null_mut() {
+    if !input.is_null() {
         // probe bytes for `rdp` protocol pattern
         let slice = build_slice!(input, input_len as usize);
 
@@ -426,7 +414,7 @@ pub extern "C" fn rs_rdp_probe_ts_tc(
         // https://wiki.wireshark.org/SampleCaptures?action=AttachFile&do=view&target=rdp-ssl.pcap.gz
         // but this callback will not be exercised, so `probe_tls_handshake` not needed here.
         if probe_rdp(slice) {
-            return unsafe { ALPROTO_RDP };
+            return ALPROTO_RDP;
         }
     }
     return ALPROTO_UNKNOWN;
@@ -434,7 +422,7 @@ pub extern "C" fn rs_rdp_probe_ts_tc(
 
 /// probe for TLS
 fn probe_tls_handshake(input: &[u8]) -> bool {
-    input.len() > 0 && input[0] == u8::from(TlsRecordType::Handshake)
+    !input.is_empty() && input[0] == u8::from(TlsRecordType::Handshake)
 }
 
 //
@@ -442,34 +430,37 @@ fn probe_tls_handshake(input: &[u8]) -> bool {
 //
 
 #[no_mangle]
-pub extern "C" fn rs_rdp_parse_ts(
+pub unsafe extern "C" fn rs_rdp_parse_ts(
     _flow: *const Flow, state: *mut std::os::raw::c_void, _pstate: *mut std::os::raw::c_void,
-    input: *const u8, input_len: u32, _data: *const std::os::raw::c_void, _flags: u8,
+    stream_slice: StreamSlice,
+    _data: *const std::os::raw::c_void
 ) -> AppLayerResult {
     let state = cast_pointer!(state, RdpState);
-    let buf = build_slice!(input, input_len as usize);
+    let buf = stream_slice.as_slice();
     // attempt to parse bytes as `rdp` protocol
     return state.parse_ts(buf);
 }
 
 #[no_mangle]
-pub extern "C" fn rs_rdp_parse_tc(
+pub unsafe extern "C" fn rs_rdp_parse_tc(
     _flow: *const Flow, state: *mut std::os::raw::c_void, _pstate: *mut std::os::raw::c_void,
-    input: *const u8, input_len: u32, _data: *const std::os::raw::c_void, _flags: u8,
+    stream_slice: StreamSlice,
+    _data: *const std::os::raw::c_void
 ) -> AppLayerResult {
     let state = cast_pointer!(state, RdpState);
-    let buf = build_slice!(input, input_len as usize);
+    let buf = stream_slice.as_slice();
     // attempt to parse bytes as `rdp` protocol
     return state.parse_tc(buf);
 }
 
 export_tx_data_get!(rs_rdp_get_tx_data, RdpTransaction);
+export_state_data_get!(rs_rdp_get_state_data, RdpState);
 
 //
 // registration
 //
 
-const PARSER_NAME: &'static [u8] = b"rdp\0";
+const PARSER_NAME: &[u8] = b"rdp\0";
 
 #[no_mangle]
 pub unsafe extern "C" fn rs_rdp_register_parser() {
@@ -489,21 +480,22 @@ pub unsafe extern "C" fn rs_rdp_register_parser() {
         parse_tc: rs_rdp_parse_tc,
         get_tx_count: rs_rdp_state_get_tx_count,
         get_tx: rs_rdp_state_get_tx,
-        tx_get_comp_st: rs_rdp_tx_get_progress_complete,
+        tx_comp_st_ts: 1,
+        tx_comp_st_tc: 1,
         tx_get_progress: rs_rdp_tx_get_progress,
-        get_de_state: rs_rdp_tx_get_detect_state,
-        set_de_state: rs_rdp_tx_set_detect_state,
-        get_events: None,
         get_eventinfo: None,
         get_eventinfo_byid: None,
         localstorage_new: None,
         localstorage_free: None,
-        get_files: None,
-        get_tx_iterator: None,
+        get_tx_files: None,
+        get_tx_iterator: Some(applayer::state_get_tx_iterator::<RdpState, RdpTransaction>),
         get_tx_data: rs_rdp_get_tx_data,
+        get_state_data: rs_rdp_get_state_data,
         apply_tx_config: None,
-        flags: APP_LAYER_PARSER_OPT_UNIDIR_TXS,
+        flags: 0,
         truncate: None,
+        get_frame_id_by_name: None,
+        get_frame_name_by_id: None,
     };
 
     let ip_proto_str = std::ffi::CString::new("tcp").unwrap();
@@ -525,25 +517,25 @@ mod tests {
     #[test]
     fn test_probe_rdp() {
         let buf: &[u8] = &[0x03, 0x00];
-        assert_eq!(true, probe_rdp(&buf));
+        assert!(probe_rdp(buf));
     }
 
     #[test]
     fn test_probe_rdp_other() {
         let buf: &[u8] = &[0x04, 0x00];
-        assert_eq!(false, probe_rdp(&buf));
+        assert!(!probe_rdp(buf));
     }
 
     #[test]
     fn test_probe_tls_handshake() {
         let buf: &[u8] = &[0x16, 0x00];
-        assert_eq!(true, probe_tls_handshake(&buf));
+        assert!(probe_tls_handshake(buf));
     }
 
     #[test]
     fn test_probe_tls_handshake_other() {
         let buf: &[u8] = &[0x17, 0x00];
-        assert_eq!(false, probe_tls_handshake(&buf));
+        assert!(!probe_tls_handshake(buf));
     }
 
     #[test]
@@ -556,10 +548,10 @@ mod tests {
         ];
         let mut state = RdpState::new();
         // will consume 0, request length + 1
-        assert_eq!(AppLayerResult::incomplete(0, 9), state.parse_ts(&buf_1));
+        assert_eq!(AppLayerResult::incomplete(0, 9), state.parse_ts(buf_1));
         assert_eq!(0, state.transactions.len());
         // exactly aligns with transaction
-        assert_eq!(AppLayerResult::ok(), state.parse_ts(&buf_2));
+        assert_eq!(AppLayerResult::ok(), state.parse_ts(buf_2));
         assert_eq!(1, state.transactions.len());
         let item = RdpTransactionItem::X224ConnectionRequest(X224ConnectionRequest {
             cdt: 0,
@@ -580,7 +572,7 @@ mod tests {
     fn test_parse_ts_other() {
         let buf: &[u8] = &[0x03, 0x00, 0x00, 0x01, 0x00];
         let mut state = RdpState::new();
-        assert_eq!(AppLayerResult::err(), state.parse_ts(&buf));
+        assert_eq!(AppLayerResult::err(), state.parse_ts(buf));
     }
 
     #[test]
@@ -589,10 +581,10 @@ mod tests {
         let buf_2: &[u8] = &[0x03, 0x00, 0x00, 0x09, 0x02, 0xf0, 0x80, 0x7f, 0x66];
         let mut state = RdpState::new();
         // will consume 0, request length + 1
-        assert_eq!(AppLayerResult::incomplete(0, 6), state.parse_tc(&buf_1));
+        assert_eq!(AppLayerResult::incomplete(0, 6), state.parse_tc(buf_1));
         assert_eq!(0, state.transactions.len());
         // exactly aligns with transaction
-        assert_eq!(AppLayerResult::ok(), state.parse_tc(&buf_2));
+        assert_eq!(AppLayerResult::ok(), state.parse_tc(buf_2));
         assert_eq!(1, state.transactions.len());
         let item = RdpTransactionItem::McsConnectResponse(McsConnectResponse {});
         assert_eq!(item, state.transactions[0].item);
@@ -602,7 +594,7 @@ mod tests {
     fn test_parse_tc_other() {
         let buf: &[u8] = &[0x03, 0x00, 0x00, 0x01, 0x00];
         let mut state = RdpState::new();
-        assert_eq!(AppLayerResult::err(), state.parse_tc(&buf));
+        assert_eq!(AppLayerResult::err(), state.parse_tc(buf));
     }
 
     #[test]
@@ -620,10 +612,10 @@ mod tests {
         state.transactions.push_back(tx0);
         state.transactions.push_back(tx1);
         assert_eq!(2, state.transactions.len());
-        assert_eq!(0, state.transactions[0].id);
-        assert_eq!(1, state.transactions[1].id);
-        assert_eq!(false, state.tls_parsing);
-        assert_eq!(false, state.bypass_parsing);
+        assert_eq!(1, state.transactions[0].id);
+        assert_eq!(2, state.transactions[1].id);
+        assert!(!state.tls_parsing);
+        assert!(!state.bypass_parsing);
     }
 
     #[test]
@@ -644,7 +636,7 @@ mod tests {
         state.transactions.push_back(tx0);
         state.transactions.push_back(tx1);
         state.transactions.push_back(tx2);
-        assert_eq!(Some(&state.transactions[1]), state.get_tx(1));
+        assert_eq!(Some(&state.transactions[1]), state.get_tx(2));
     }
 
     #[test]
@@ -668,8 +660,8 @@ mod tests {
         state.free_tx(1);
         assert_eq!(3, state.next_id);
         assert_eq!(2, state.transactions.len());
-        assert_eq!(0, state.transactions[0].id);
-        assert_eq!(2, state.transactions[1].id);
+        assert_eq!(2, state.transactions[0].id);
+        assert_eq!(3, state.transactions[1].id);
         assert_eq!(None, state.get_tx(1));
     }
 }
