@@ -24,10 +24,7 @@
 #ifndef __APP_LAYER_ENIP_COMMON_H__
 #define __APP_LAYER_ENIP_COMMON_H__
 
-#include "app-layer-protos.h"
-#include "app-layer-parser.h"
-#include "flow.h"
-#include "queue.h"
+#include "rust.h"
 
 // EtherNet/IP commands
 #define NOP                0x0000
@@ -116,13 +113,12 @@ typedef struct ENIPEncapDataHdr_
 /**
  * ENIP encapsulation address item
  */
-typedef struct ENIPEncapAddresItem_
-{
+typedef struct ENIPEncapAddressItem_ {
     uint16_t type;
     uint16_t length;
-    uint16_t conn_id;
-    uint16_t sequence_num;
-} ENIPEncapAddresItem;
+    uint32_t conn_id;
+    uint32_t sequence_num;
+} ENIPEncapAddressItem;
 
 /**
  * ENIP encapsulation data item
@@ -182,7 +178,7 @@ typedef struct CIPServiceEntry_
         } request;
         struct
         {
-            uint8_t status;
+            uint16_t status;
         } response;
     };
 
@@ -195,27 +191,25 @@ typedef struct CIPServiceEntry_
 typedef struct ENIPTransaction_
 {
     struct ENIPState_ *enip;
-    uint16_t tx_num;                            /**< internal: id */
+    uint64_t tx_num;                            /**< internal: id */
     uint16_t tx_id;                             /**< transaction id */
     uint16_t service_count;
 
     ENIPEncapHdr header;                        /**< encapsulation header */
     ENIPEncapDataHdr encap_data_header;         /**< encapsulation data header */
-    ENIPEncapAddresItem encap_addr_item;        /**< encapsulated address item */
+    ENIPEncapAddressItem encap_addr_item;       /**< encapsulated address item */
     ENIPEncapDataItem encap_data_item;          /**< encapsulated data item */
 
     TAILQ_HEAD(, CIPServiceEntry_) service_list; /**< list for CIP  */
 
-    AppLayerDecoderEvents *decoder_events;      /**< per tx events */
-
     TAILQ_ENTRY(ENIPTransaction_) next;
-    DetectEngineState *de_state;
     AppLayerTxData tx_data;
 } ENIPTransaction;
 
 /** \brief Per flow ENIP state container */
 typedef struct ENIPState_
 {
+    AppLayerStateData state_data;
     TAILQ_HEAD(, ENIPTransaction_) tx_list; /**< transaction list */
     ENIPTransaction *curr;                  /**< ptr to current tx */
     ENIPTransaction *iter;
