@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2022 Open Information Security Foundation
+/* Copyright (C) 2007-2010 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -33,19 +33,9 @@
 #include "suricata-common.h"
 #include "decode-icmpv6.h"
 #include "decode.h"
-#include "decode-tcp.h"
-#include "decode-sctp.h"
-#include "decode-udp.h"
-#include "decode-events.h"
-#include "util-unittest.h"
 #include "flow.h"
-#include "util-debug.h"
 #include "util-print.h"
-
-#include "pkt-var.h"
-#include "util-profiling.h"
-#include "host.h"
-
+#include "util-validate.h"
 
 /**
  * \brief Get variables and do some checks of the embedded IPV6 packet
@@ -201,7 +191,8 @@ int DecodeICMPV6(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p,
     p->proto = IPPROTO_ICMPV6;
     p->icmp_s.type = p->icmpv6h->type;
     p->icmp_s.code = p->icmpv6h->code;
-    p->payload_len = len - ICMPV6_HEADER_LEN;
+    DEBUG_VALIDATE_BUG_ON(len - ICMPV6_HEADER_LEN > UINT16_MAX);
+    p->payload_len = (uint16_t)(len - ICMPV6_HEADER_LEN);
     p->payload = (uint8_t *)pkt + ICMPV6_HEADER_LEN;
 
     int ctype = ICMPv6GetCounterpart(p->icmp_s.type);
@@ -222,8 +213,8 @@ int DecodeICMPV6(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p,
                 if (unlikely(len > ICMPV6_HEADER_LEN + USHRT_MAX)) {
                     return TM_ECODE_FAILED;
                 }
-                DecodePartialIPV6(p, (uint8_t*) (pkt + ICMPV6_HEADER_LEN),
-                                  len - ICMPV6_HEADER_LEN );
+                DecodePartialIPV6(p, (uint8_t *)(pkt + ICMPV6_HEADER_LEN),
+                        (uint16_t)(len - ICMPV6_HEADER_LEN));
                 full_hdr = 1;
             }
 
@@ -238,8 +229,8 @@ int DecodeICMPV6(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p,
                     return TM_ECODE_FAILED;
                 }
                 p->icmpv6vars.mtu = ICMPV6_GET_MTU(p);
-                DecodePartialIPV6(p, (uint8_t*) (pkt + ICMPV6_HEADER_LEN),
-                                  len - ICMPV6_HEADER_LEN );
+                DecodePartialIPV6(p, (uint8_t *)(pkt + ICMPV6_HEADER_LEN),
+                        (uint16_t)(len - ICMPV6_HEADER_LEN));
                 full_hdr = 1;
             }
 
@@ -253,8 +244,8 @@ int DecodeICMPV6(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p,
                 if (unlikely(len > ICMPV6_HEADER_LEN + USHRT_MAX)) {
                     return TM_ECODE_FAILED;
                 }
-                DecodePartialIPV6(p, (uint8_t*) (pkt + ICMPV6_HEADER_LEN),
-                                  len - ICMPV6_HEADER_LEN );
+                DecodePartialIPV6(p, (uint8_t *)(pkt + ICMPV6_HEADER_LEN),
+                        (uint16_t)(len - ICMPV6_HEADER_LEN));
                 full_hdr = 1;
             }
 
@@ -269,8 +260,8 @@ int DecodeICMPV6(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p,
                     return TM_ECODE_FAILED;
                 }
                 p->icmpv6vars.error_ptr= ICMPV6_GET_ERROR_PTR(p);
-                DecodePartialIPV6(p, (uint8_t*) (pkt + ICMPV6_HEADER_LEN),
-                                  len - ICMPV6_HEADER_LEN );
+                DecodePartialIPV6(p, (uint8_t *)(pkt + ICMPV6_HEADER_LEN),
+                        (uint16_t)(len - ICMPV6_HEADER_LEN));
                 full_hdr = 1;
             }
 
@@ -529,6 +520,8 @@ int DecodeICMPV6(ThreadVars *tv, DecodeThreadVars *dtv, Packet *p,
 }
 
 #ifdef UNITTESTS
+#include "packet.h"
+#include "util-unittest-helper.h"
 
 static int ICMPV6CalculateValidChecksumtest01(void)
 {
@@ -638,7 +631,7 @@ static int ICMPV6ParamProbTest01(void)
             p->icmpv6vars.emb_ip6_dst[i] != ipv6dst[i]);
     }
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -696,7 +689,7 @@ static int ICMPV6PktTooBigTest01(void)
 
     SCLogDebug("ICMPV6 IPV6 src and dst properly set");
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -754,7 +747,7 @@ static int ICMPV6TimeExceedTest01(void)
 
     SCLogDebug("ICMPV6 IPV6 src and dst properly set");
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -810,7 +803,7 @@ static int ICMPV6DestUnreachTest01(void)
             p->icmpv6vars.emb_ip6_dst[i] != ipv6dst[i]);
     }
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -854,7 +847,7 @@ static int ICMPV6EchoReqTest01(void)
         FAIL;
     }
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -900,7 +893,7 @@ static int ICMPV6EchoRepTest01(void)
         FAIL;
     }
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -943,7 +936,7 @@ static int ICMPV6ParamProbTest02(void)
     FAIL_IF(ICMPV6_GET_TYPE(p) != 4 || ICMPV6_GET_CODE(p) != 0);
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_IPV6_UNKNOWN_VER));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -984,7 +977,7 @@ static int ICMPV6PktTooBigTest02(void)
     FAIL_IF_NULL(p->icmpv6h);
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1021,7 +1014,7 @@ static int ICMPV6TimeExceedTest02(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_PKT_TOO_SMALL));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1061,7 +1054,7 @@ static int ICMPV6DestUnreachTest02(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_IPV6_TRUNC_PKT));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1097,7 +1090,7 @@ static int ICMPV6EchoReqTest02(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1133,13 +1126,13 @@ static int ICMPV6EchoRepTest02(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
 }
 
-/**\test icmpv6 packet decoding and setting up of payload_len and payload buufer
+/**\test icmpv6 packet decoding and setting up of payload_len and payload buffer
  * \retval retval 0 = Error ; 1 = ok
  */
 static int ICMPV6PayloadTest01(void)
@@ -1173,7 +1166,7 @@ static int ICMPV6PayloadTest01(void)
     FAIL_IF_NULL(p->payload);
     FAIL_IF(p->payload_len != 37);
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1205,7 +1198,7 @@ static int ICMPV6RouterSolicitTestKnownCode(void)
 
     FAIL_IF(ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1237,7 +1230,7 @@ static int ICMPV6RouterSolicitTestUnknownCode(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1269,7 +1262,7 @@ static int ICMPV6RouterAdvertTestKnownCode(void)
 
     FAIL_IF(ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1301,7 +1294,7 @@ static int ICMPV6RouterAdvertTestUnknownCode(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1333,7 +1326,7 @@ static int ICMPV6NeighbourSolicitTestKnownCode(void)
 
     FAIL_IF(ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1365,7 +1358,7 @@ static int ICMPV6NeighbourSolicitTestUnknownCode(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1397,7 +1390,7 @@ static int ICMPV6NeighbourAdvertTestKnownCode(void)
 
     FAIL_IF(ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1429,7 +1422,7 @@ static int ICMPV6NeighbourAdvertTestUnknownCode(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1461,7 +1454,7 @@ static int ICMPV6RedirectTestKnownCode(void)
 
     FAIL_IF(ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1493,7 +1486,7 @@ static int ICMPV6RedirectTestUnknownCode(void)
 
     FAIL_IF(!ENGINE_ISSET_EVENT(p, ICMPV6_UNKNOWN_CODE));
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1547,7 +1540,7 @@ static int ICMPV6CalculateValidChecksumWithFCS(void)
     FAIL_IF(ICMPV6CalculateChecksum(p->ip6h->s_ip6_addrs,
             (uint16_t *)p->icmpv6h, icmpv6_len) != csum);
 
-    PACKET_RECYCLE(p);
+    PacketRecycle(p);
     FlowShutdown();
     SCFree(p);
     PASS;
@@ -1563,8 +1556,7 @@ void DecodeICMPV6RegisterTests(void)
 #ifdef UNITTESTS
     UtRegisterTest("ICMPV6CalculateValidChecksumtest01",
                    ICMPV6CalculateValidChecksumtest01);
-    UtRegisterTest("ICMPV6CalculateInValidChecksumtest02",
-                   ICMPV6CalculateInvalidChecksumtest02);
+    UtRegisterTest("ICMPV6CalculateInvalidChecksumtest02", ICMPV6CalculateInvalidChecksumtest02);
 
     UtRegisterTest("ICMPV6ParamProbTest01 (Valid)", ICMPV6ParamProbTest01);
     UtRegisterTest("ICMPV6DestUnreachTest01 (Valid)", ICMPV6DestUnreachTest01);
