@@ -31,5 +31,4 @@ typedef struct DetectIcmpSeqData_ {
 /* prototypes */
 void DetectIcmpSeqRegister(void);
 
-#endif /* __DETECT_ICMP_SEQ__ */
-
+#endif /* __DETECT_ICMP_SEQ_H__ */
