@@ -1,4 +1,4 @@
-/* Copyright (C) 2018 Open Information Security Foundation
+/* Copyright (C) 2018-2022 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -35,6 +35,7 @@
 
 #include "rust.h"
 #include "app-layer-krb5.h"
+#include "util-profiling.h"
 
 static int g_krb5_sname_buffer_id = 0;
 
@@ -45,7 +46,7 @@ struct Krb5PrincipalNameDataArgs {
 
 static int DetectKrb5SNameSetup(DetectEngineCtx *de_ctx, Signature *s, const char *arg)
 {
-    if (DetectBufferSetActiveList(s, g_krb5_sname_buffer_id) < 0)
+    if (DetectBufferSetActiveList(de_ctx, s, g_krb5_sname_buffer_id) < 0)
         return -1;
 
     if (DetectSignatureSetAppProto(s, ALPROTO_KRB5) != 0)
@@ -55,9 +56,8 @@ static int DetectKrb5SNameSetup(DetectEngineCtx *de_ctx, Signature *s, const cha
 }
 
 static InspectionBuffer *GetKrb5SNameData(DetectEngineThreadCtx *det_ctx,
-        const DetectEngineTransforms *transforms,
-        Flow *_f, const struct Krb5PrincipalNameDataArgs *cbdata,
-        int list_id, bool first)
+        const DetectEngineTransforms *transforms, Flow *_f,
+        const struct Krb5PrincipalNameDataArgs *cbdata, int list_id)
 {
     SCEnter();
 
@@ -65,27 +65,29 @@ static InspectionBuffer *GetKrb5SNameData(DetectEngineThreadCtx *det_ctx,
             InspectionBufferMultipleForListGet(det_ctx, list_id, cbdata->local_id);
     if (buffer == NULL)
         return NULL;
-    if (!first && buffer->inspect != NULL)
+    if (buffer->initialized)
         return buffer;
 
     uint32_t b_len = 0;
     const uint8_t *b = NULL;
 
-    if (rs_krb5_tx_get_sname(cbdata->txv, cbdata->local_id, &b, &b_len) != 1)
+    if (rs_krb5_tx_get_sname(cbdata->txv, cbdata->local_id, &b, &b_len) != 1) {
+        InspectionBufferSetupMultiEmpty(buffer);
         return NULL;
-    if (b == NULL || b_len == 0)
+    }
+    if (b == NULL || b_len == 0) {
+        InspectionBufferSetupMultiEmpty(buffer);
         return NULL;
+    }
 
     InspectionBufferSetupMulti(buffer, transforms, b, b_len);
 
     SCReturnPtr(buffer, "InspectionBuffer");
 }
 
-static int DetectEngineInspectKrb5SName(
-        DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx,
-        const DetectEngineAppInspectionEngine *engine,
-        const Signature *s,
-        Flow *f, uint8_t flags, void *alstate, void *txv, uint64_t tx_id)
+static uint8_t DetectEngineInspectKrb5SName(DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx,
+        const DetectEngineAppInspectionEngine *engine, const Signature *s, Flow *f, uint8_t flags,
+        void *alstate, void *txv, uint64_t tx_id)
 {
     uint32_t local_id = 0;
 
@@ -96,8 +98,8 @@ static int DetectEngineInspectKrb5SName(
 
     while (1) {
         struct Krb5PrincipalNameDataArgs cbdata = { local_id, txv, };
-        InspectionBuffer *buffer = GetKrb5SNameData(det_ctx,
-                transforms, f, &cbdata, engine->sm_list, false);
+        InspectionBuffer *buffer =
+                GetKrb5SNameData(det_ctx, transforms, f, &cbdata, engine->sm_list);
 
         if (buffer == NULL || buffer->inspect == NULL)
             break;
@@ -135,10 +137,8 @@ typedef struct PrefilterMpmKrb5Name {
  *  \param txv tx to inspect
  *  \param pectx inspection context
  */
-static void PrefilterTxKrb5SName(DetectEngineThreadCtx *det_ctx,
-        const void *pectx,
-        Packet *p, Flow *f, void *txv,
-        const uint64_t idx, const uint8_t flags)
+static void PrefilterTxKrb5SName(DetectEngineThreadCtx *det_ctx, const void *pectx, Packet *p,
+        Flow *f, void *txv, const uint64_t idx, const AppLayerTxData *_txd, const uint8_t flags)
 {
     SCEnter();
 
@@ -152,8 +152,7 @@ static void PrefilterTxKrb5SName(DetectEngineThreadCtx *det_ctx,
         // loop until we get a NULL
 
         struct Krb5PrincipalNameDataArgs cbdata = { local_id, txv };
-        InspectionBuffer *buffer = GetKrb5SNameData(det_ctx, ctx->transforms,
-                f, &cbdata, list_id, true);
+        InspectionBuffer *buffer = GetKrb5SNameData(det_ctx, ctx->transforms, f, &cbdata, list_id);
         if (buffer == NULL)
             break;
 
@@ -161,6 +160,7 @@ static void PrefilterTxKrb5SName(DetectEngineThreadCtx *det_ctx,
             (void)mpm_table[mpm_ctx->mpm_type].Search(mpm_ctx,
                     &det_ctx->mtcu, &det_ctx->pmq,
                     buffer->inspect, buffer->inspect_len);
+            PREFILTER_PROFILING_ADD_BYTES(det_ctx, buffer->inspect_len);
         }
 
         local_id++;
@@ -172,9 +172,8 @@ static void PrefilterMpmKrb5NameFree(void *ptr)
     SCFree(ptr);
 }
 
-static int PrefilterMpmKrb5SNameRegister(DetectEngineCtx *de_ctx,
-        SigGroupHead *sgh, MpmCtx *mpm_ctx,
-        const DetectBufferMpmRegistery *mpm_reg, int list_id)
+static int PrefilterMpmKrb5SNameRegister(DetectEngineCtx *de_ctx, SigGroupHead *sgh,
+        MpmCtx *mpm_ctx, const DetectBufferMpmRegistry *mpm_reg, int list_id)
 {
     PrefilterMpmKrb5Name *pectx = SCCalloc(1, sizeof(*pectx));
     if (pectx == NULL)
@@ -209,4 +208,6 @@ void DetectKrb5SNameRegister(void)
             "Kerberos 5 ticket server name");
 
     g_krb5_sname_buffer_id = DetectBufferTypeGetByName("krb5_sname");
+
+    DetectBufferTypeSupportsMultiInstance("krb5_sname");
 }
