@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2021 Open Information Security Foundation
+/* Copyright (C) 2007-2022 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -27,7 +27,6 @@
 #include "conf.h"
 
 #include "threads.h"
-#include "debug.h"
 #include "decode.h"
 
 #include "detect.h"
@@ -215,7 +214,7 @@ static int LuaGetFlowvar(lua_State *luastate)
         return ret;
 
     if (lua_isnumber(luastate, 1)) {
-        ret = GetFlowVarById(luastate, f, &fv, FALSE, NULL);
+        ret = GetFlowVarById(luastate, f, &fv, false, NULL);
         if (ret != 0 || fv == NULL)
             return ret;
     } else if (lua_isstring(luastate, 1)) {
@@ -246,7 +245,7 @@ static int LuaSetFlowvarById(lua_State *luastate)
     if (ret != 0)
         return ret;
 
-    ret = GetFlowVarById(luastate, f, &fv, TRUE, &idx);
+    ret = GetFlowVarById(luastate, f, &fv, true, &idx);
     if (ret != 0)
         return ret;
 
@@ -359,7 +358,7 @@ static int LuaGetFlowint(lua_State *luastate)
     if (ret != 0)
         return ret;
 
-    ret = GetFlowIntById(luastate, f, &fv, FALSE, NULL);
+    ret = GetFlowIntById(luastate, f, &fv, false, NULL);
     if (ret != 0)
         return ret;
 
@@ -429,7 +428,7 @@ static int LuaIncrFlowint(lua_State *luastate)
     if (ret != 0)
         return ret;
 
-    ret = GetFlowIntById(luastate, f, &fv, TRUE, &idx);
+    ret = GetFlowIntById(luastate, f, &fv, true, &idx);
     if (ret != 0)
         return ret;
 
@@ -461,7 +460,7 @@ static int LuaDecrFlowint(lua_State *luastate)
     if (ret != 0)
         return ret;
 
-    ret = GetFlowIntById(luastate, f, &fv, TRUE, &idx);
+    ret = GetFlowIntById(luastate, f, &fv, true, &idx);
     if (ret != 0)
         return ret;
 
@@ -481,8 +480,34 @@ static int LuaDecrFlowint(lua_State *luastate)
 
 }
 
-void LuaExtensionsMatchSetup(lua_State *lua_state, DetectLuaData *ld, DetectEngineThreadCtx *det_ctx,
-        Flow *f, Packet *p, uint8_t flags)
+static int LuaGetByteVar(lua_State *luastate)
+{
+    DetectLuaData *ld = NULL;
+    DetectEngineThreadCtx *det_ctx = LuaStateGetDetCtx(luastate);
+
+    if (det_ctx == NULL)
+        return LuaCallbackError(luastate, "internal error: no ldet_ctx");
+
+    int ret = GetLuaData(luastate, &ld);
+    if (ret != 0)
+        return ret;
+
+    if (!lua_isnumber(luastate, 1)) {
+        LUA_ERROR("bytevar id not a number");
+    }
+    int id = lua_tonumber(luastate, 1);
+    if (id < 0 || id >= DETECT_LUAJIT_MAX_BYTEVARS) {
+        LUA_ERROR("bytevar id out of range");
+    }
+    uint32_t idx = ld->bytevar[id];
+
+    lua_pushinteger(luastate, det_ctx->byte_values[idx]);
+
+    return 1;
+}
+
+void LuaExtensionsMatchSetup(lua_State *lua_state, DetectLuaData *ld,
+        DetectEngineThreadCtx *det_ctx, Flow *f, Packet *p, const Signature *s, uint8_t flags)
 {
     SCLogDebug("det_ctx %p, f %p", det_ctx, f);
 
@@ -491,13 +516,16 @@ void LuaExtensionsMatchSetup(lua_State *lua_state, DetectLuaData *ld, DetectEngi
     lua_pushlightuserdata(lua_state, (void *)ld);
     lua_settable(lua_state, LUA_REGISTRYINDEX);
 
+    LuaStateSetSignature(lua_state, s);
+
     LuaStateSetFlow(lua_state, f);
+    LuaStateSetDetCtx(lua_state, det_ctx);
 
     if (det_ctx->tx_id_set) {
         if (f && f->alstate) {
             void *txptr = AppLayerParserGetTx(f->proto, f->alproto, f->alstate, det_ctx->tx_id);
             if (txptr) {
-                LuaStateSetTX(lua_state, txptr);
+                LuaStateSetTX(lua_state, txptr, det_ctx->tx_id);
             }
         }
     }
@@ -549,6 +577,9 @@ int LuaRegisterExtensions(lua_State *lua_state)
     lua_pushcfunction(lua_state, LuaDecrFlowint);
     lua_setglobal(lua_state, "SCFlowintDecr");
 
+    lua_pushcfunction(lua_state, LuaGetByteVar);
+    lua_setglobal(lua_state, "SCByteVarGet");
+
     LuaRegisterFunctions(lua_state);
     LuaRegisterHttpFunctions(lua_state);
     LuaRegisterDnsFunctions(lua_state);
