@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Open Information Security Foundation
+/* Copyright (C) 2017-2022 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -25,7 +25,6 @@
 
 #include "suricata-common.h"
 #include "threads.h"
-#include "debug.h"
 #include "decode.h"
 #include "detect.h"
 
@@ -41,7 +40,6 @@
 #include "flow-var.h"
 
 #include "util-debug.h"
-#include "util-unittest.h"
 #include "util-spm.h"
 #include "util-print.h"
 
@@ -75,7 +73,8 @@ void DetectTlsSerialRegister(void)
 {
     sigmatch_table[DETECT_AL_TLS_CERT_SERIAL].name = "tls.cert_serial";
     sigmatch_table[DETECT_AL_TLS_CERT_SERIAL].alias = "tls_cert_serial";
-    sigmatch_table[DETECT_AL_TLS_CERT_SERIAL].desc = "content modifier to match the TLS cert serial buffer";
+    sigmatch_table[DETECT_AL_TLS_CERT_SERIAL].desc =
+            "sticky buffer to match the TLS cert serial buffer";
     sigmatch_table[DETECT_AL_TLS_CERT_SERIAL].url = "/rules/tls-keywords.html#tls-cert-serial";
     sigmatch_table[DETECT_AL_TLS_CERT_SERIAL].Setup = DetectTlsSerialSetup;
 #ifdef UNITTESTS
@@ -92,6 +91,12 @@ void DetectTlsSerialRegister(void)
             PrefilterGenericMpmRegister, GetData, ALPROTO_TLS,
             TLS_STATE_CERT_READY);
 
+    DetectAppLayerInspectEngineRegister2("tls.cert_serial", ALPROTO_TLS, SIG_FLAG_TOSERVER,
+            TLS_STATE_CERT_READY, DetectEngineInspectBufferGeneric, GetData);
+
+    DetectAppLayerMpmRegister2("tls.cert_serial", SIG_FLAG_TOSERVER, 2, PrefilterGenericMpmRegister,
+            GetData, ALPROTO_TLS, TLS_STATE_CERT_READY);
+
     DetectBufferTypeSetDescriptionByName("tls.cert_serial",
             "TLS certificate serial number");
 
@@ -116,7 +121,7 @@ void DetectTlsSerialRegister(void)
  */
 static int DetectTlsSerialSetup(DetectEngineCtx *de_ctx, Signature *s, const char *str)
 {
-    if (DetectBufferSetActiveList(s, g_tls_cert_serial_buffer_id) < 0)
+    if (DetectBufferSetActiveList(de_ctx, s, g_tls_cert_serial_buffer_id) < 0)
         return -1;
 
     if (DetectSignatureSetAppProto(s, ALPROTO_TLS) < 0)
@@ -132,13 +137,20 @@ static InspectionBuffer *GetData(DetectEngineThreadCtx *det_ctx,
     InspectionBuffer *buffer = InspectionBufferGet(det_ctx, list_id);
     if (buffer->inspect == NULL) {
         const SSLState *ssl_state = (SSLState *)f->alstate;
+        const SSLStateConnp *connp;
 
-        if (ssl_state->server_connp.cert0_serial == NULL) {
+        if (flow_flags & STREAM_TOSERVER) {
+            connp = &ssl_state->client_connp;
+        } else {
+            connp = &ssl_state->server_connp;
+        }
+
+        if (connp->cert0_serial == NULL) {
             return NULL;
         }
 
-        const uint32_t data_len = strlen(ssl_state->server_connp.cert0_serial);
-        const uint8_t *data = (uint8_t *)ssl_state->server_connp.cert0_serial;
+        const uint32_t data_len = strlen(connp->cert0_serial);
+        const uint8_t *data = (uint8_t *)connp->cert0_serial;
 
         InspectionBufferSetup(det_ctx, list_id, buffer, data, data_len);
         InspectionBufferApplyTransforms(buffer, transforms);
@@ -150,67 +162,71 @@ static InspectionBuffer *GetData(DetectEngineThreadCtx *det_ctx,
 static bool DetectTlsSerialValidateCallback(const Signature *s,
                                              const char **sigerror)
 {
-    const SigMatch *sm = s->init_data->smlists[g_tls_cert_serial_buffer_id];
-    for ( ; sm != NULL; sm = sm->next)
-    {
-        if (sm->type != DETECT_CONTENT)
+    for (uint32_t x = 0; x < s->init_data->buffer_index; x++) {
+        if (s->init_data->buffers[x].id != (uint32_t)g_tls_cert_serial_buffer_id)
             continue;
+        const SigMatch *sm = s->init_data->buffers[x].head;
+        for (; sm != NULL; sm = sm->next) {
+            if (sm->type != DETECT_CONTENT)
+                continue;
 
-        const DetectContentData *cd = (DetectContentData *)sm->ctx;
+            const DetectContentData *cd = (DetectContentData *)sm->ctx;
 
-        if (cd->flags & DETECT_CONTENT_NOCASE) {
-            *sigerror = "tls.cert_serial should not be used together "
-                        "with nocase, since the rule is automatically "
-                        "uppercased anyway which makes nocase redundant.";
-            SCLogWarning(SC_WARN_POOR_RULE, "rule %u: %s", s->id, *sigerror);
+            if (cd->flags & DETECT_CONTENT_NOCASE) {
+                *sigerror = "tls.cert_serial should not be used together "
+                            "with nocase, since the rule is automatically "
+                            "uppercased anyway which makes nocase redundant.";
+                SCLogWarning("rule %u: %s", s->id, *sigerror);
+            }
+
+            /* no need to worry about this if the content is short enough */
+            if (cd->content_len <= 2)
+                return true;
+
+            uint32_t u;
+            for (u = 0; u < cd->content_len; u++)
+                if (cd->content[u] == ':')
+                    return true;
+
+            *sigerror = "No colon delimiters ':' detected in content after "
+                        "tls.cert_serial. This rule will therefore never "
+                        "match.";
+            SCLogWarning("rule %u: %s", s->id, *sigerror);
+
+            return false;
         }
-
-        /* no need to worry about this if the content is short enough */
-        if (cd->content_len <= 2)
-            return TRUE;
-
-        uint32_t u;
-        for (u = 0; u < cd->content_len; u++)
-            if (cd->content[u] == ':')
-                return TRUE;
-
-        *sigerror = "No colon delimiters ':' detected in content after "
-                    "tls.cert_serial. This rule will therefore never "
-                    "match.";
-        SCLogWarning(SC_WARN_POOR_RULE, "rule %u: %s", s->id, *sigerror);
-
-        return FALSE;
     }
-
-    return TRUE;
+    return true;
 }
 
 static void DetectTlsSerialSetupCallback(const DetectEngineCtx *de_ctx,
                                          Signature *s)
 {
-    SigMatch *sm = s->init_data->smlists[g_tls_cert_serial_buffer_id];
-    for ( ; sm != NULL; sm = sm->next)
-    {
-        if (sm->type != DETECT_CONTENT)
+    for (uint32_t x = 0; x < s->init_data->buffer_index; x++) {
+        if (s->init_data->buffers[x].id != (uint32_t)g_tls_cert_serial_buffer_id)
             continue;
+        SigMatch *sm = s->init_data->buffers[x].head;
+        for (; sm != NULL; sm = sm->next) {
+            if (sm->type != DETECT_CONTENT)
+                continue;
 
-        DetectContentData *cd = (DetectContentData *)sm->ctx;
+            DetectContentData *cd = (DetectContentData *)sm->ctx;
 
-        bool changed = FALSE;
-        uint32_t u;
-        for (u = 0; u < cd->content_len; u++)
-        {
-            if (islower(cd->content[u])) {
-                cd->content[u] = toupper(cd->content[u]);
-                changed = TRUE;
+            bool changed = false;
+            uint32_t u;
+            for (u = 0; u < cd->content_len; u++) {
+                if (islower(cd->content[u])) {
+                    cd->content[u] = u8_toupper(cd->content[u]);
+                    changed = true;
+                }
             }
-        }
 
-        /* recreate the context if changes were made */
-        if (changed) {
-            SpmDestroyCtx(cd->spm_ctx);
-            cd->spm_ctx = SpmInitCtx(cd->content, cd->content_len, 1,
-                                     de_ctx->spm_global_thread_ctx);
+            /* recreate the context if changes were made */
+            if (changed) {
+                SpmDestroyCtx(cd->spm_ctx);
+                cd->spm_ctx =
+                        SpmInitCtx(cd->content, cd->content_len, 1, de_ctx->spm_global_thread_ctx);
+            }
         }
     }
 }
