@@ -25,7 +25,6 @@
 
 #include "suricata-common.h"
 #include "threads.h"
-#include "debug.h"
 #include "flow-private.h"
 #include "flow-queue.h"
 #include "flow-util.h"
@@ -37,7 +36,7 @@ FlowQueue *FlowQueueNew(void)
 {
     FlowQueue *q = (FlowQueue *)SCMalloc(sizeof(FlowQueue));
     if (q == NULL) {
-        SCLogError(SC_ERR_FATAL, "Fatal error encountered in FlowQueueNew. Exiting...");
+        SCLogError("Fatal error encountered in FlowQueueNew. Exiting...");
         exit(EXIT_SUCCESS);
     }
     q = FlowQueueInit(q);
