@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2013 Open Information Security Foundation
+/* Copyright (C) 2007-2021 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -25,10 +25,12 @@
 #define __OUTPUT_JSON_FILE_H__
 
 #include "app-layer-htp-xff.h"
-#include "output-json.h"
+
+typedef struct OutputJsonCtx_ OutputJsonCtx;
 
 void JsonFileLogRegister(void);
-JsonBuilder *JsonBuildFileInfoRecord(const Packet *p, const File *ff, const bool stored,
-        uint8_t dir, HttpXFFCfg *xff_cfg, OutputJsonCommonSettings *cfg);
+JsonBuilder *JsonBuildFileInfoRecord(const Packet *p, const File *ff, void *tx,
+        const uint64_t tx_id, const bool stored, uint8_t dir, HttpXFFCfg *xff_cfg,
+        OutputJsonCtx *eve_ctx);
 
 #endif /* __OUTPUT_JSON_FILE_H__ */
