@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Open Information Security Foundation
+/* Copyright (C) 2017-2020 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -25,6 +25,8 @@
 #define __OUTPUT_JSON_NFS_H__
 
 void JsonNFSLogRegister(void);
-json_t *JsonNFSAddMetadataRPC(const Flow *f, uint64_t tx_id);
-json_t *JsonNFSAddMetadata(const Flow *f, uint64_t tx_id);
+
+bool EveNFSAddMetadataRPC(const Flow *f, uint64_t tx_id, JsonBuilder *jb);
+bool EveNFSAddMetadata(const Flow *f, uint64_t tx_id, JsonBuilder *jb);
+
 #endif /* __OUTPUT_JSON_NFS_H__ */
