@@ -1,4 +1,4 @@
-/* Copyright (C) 2015 Open Information Security Foundation
+/* Copyright (C) 2018 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -21,9 +21,9 @@
  * \author FirstName LastName <name@domain>
  */
 
-#ifndef __OUTPUT_JSON_TEMPLATE_H__
-#define __OUTPUT_JSON_TEMPLATE_H__
+#ifndef __OUTPUT_JSON_TEMPLATE_RUST_H__
+#define __OUTPUT_JSON_TEMPLATE_RUST_H__
 
 void JsonTemplateLogRegister(void);
 
-#endif /* __OUTPUT_JSON_TEMPLATE_H__ */
+#endif /* __OUTPUT_JSON_TEMPLATE_RUST_H__ */
