@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2020 Open Information Security Foundation
+/* Copyright (C) 2007-2023 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -28,11 +28,10 @@
  *  \todo come up with a way for users to specify icmp unreachable type
  *  \todo Possibly default to port unreachable for UDP traffic this seems
  *        to be the default in flexresp and iptables
- *  \todo implement ipv6 resets
- *  \todo implement pre-alloc resets for speed
  */
 
 #include "suricata-common.h"
+#include "suricata.h"
 
 #include "decode.h"
 #include "decode-ipv4.h"
@@ -80,7 +79,7 @@ typedef struct Libnet11Packet_ {
     struct libnet_in6_addr src6, dst6;
     uint32_t src4, dst4;
     uint16_t sp, dp;
-    size_t len;
+    uint16_t len;
     uint8_t *smac, *dmac;
 } Libnet11Packet;
 
@@ -108,7 +107,7 @@ static inline libnet_t *GetCtx(const Packet *p, int injection_type)
     char ebuf[LIBNET_ERRBUF_SIZE];
     libnet_t *c = libnet_init(injection_type, LIBNET_INIT_CAST devname, ebuf);
     if (c == NULL) {
-        SCLogError(SC_ERR_LIBNET_INIT,"libnet_init failed: %s", ebuf);
+        SCLogError("libnet_init failed: %s", ebuf);
     }
     if (store_ctx) {
         t_c = c;
@@ -185,7 +184,7 @@ static inline int BuildTCP(libnet_t *c, Libnet11Packet *lpacket)
                     c,                     /* libnet context */
                     0)) < 0)               /* libnet ptag */
     {
-        SCLogError(SC_ERR_LIBNET_BUILD_FAILED,"libnet_build_tcp %s", libnet_geterror(c));
+        SCLogError("libnet_build_tcp %s", libnet_geterror(c));
         return -1;
     }
     return 0;
@@ -208,7 +207,7 @@ static inline int BuildIPv4(libnet_t *c, Libnet11Packet *lpacket, const uint8_t
                     c,                            /* libnet context pointer */
                     0)) < 0)                      /* packet id */
     {
-        SCLogError(SC_ERR_LIBNET_BUILD_FAILED,"libnet_build_ipv4 %s", libnet_geterror(c));
+        SCLogError("libnet_build_ipv4 %s", libnet_geterror(c));
         return -1;
     }
     return 0;
@@ -229,7 +228,7 @@ static inline int BuildIPv6(libnet_t *c, Libnet11Packet *lpacket, const uint8_t
                     c,                            /* libnet context pointer */
                     0)) < 0)                      /* packet id */
     {
-        SCLogError(SC_ERR_LIBNET_BUILD_FAILED,"libnet_build_ipv6 %s", libnet_geterror(c));
+        SCLogError("libnet_build_ipv6 %s", libnet_geterror(c));
         return -1;
     }
     return 0;
@@ -253,7 +252,7 @@ static inline void SetupEthernet(Packet *p, Libnet11Packet *lpacket, enum Reject
 static inline int BuildEthernet(libnet_t *c, Libnet11Packet *lpacket, uint16_t proto)
 {
     if ((libnet_build_ethernet(lpacket->dmac,lpacket->smac, proto , NULL, 0, c, 0)) < 0) {
-        SCLogError(SC_ERR_LIBNET_BUILD_FAILED,"libnet_build_ethernet %s", libnet_geterror(c));
+        SCLogError("libnet_build_ethernet %s", libnet_geterror(c));
         return -1;
     }
     return 0;
@@ -261,15 +260,12 @@ static inline int BuildEthernet(libnet_t *c, Libnet11Packet *lpacket, uint16_t p
 
 static inline int BuildEthernetVLAN(libnet_t *c, Libnet11Packet *lpacket, uint16_t proto, uint16_t vlan_id)
 {
-    if (libnet_build_802_1q(
-                lpacket->dmac, lpacket->smac, ETHERTYPE_VLAN,
-                0x000, 0x000, vlan_id, proto,
-                NULL,                                   /* payload */
-                0,                                      /* payload size */
-                c,                                      /* libnet handle */
-                0) < 0)
-    {
-        SCLogError(SC_ERR_LIBNET_BUILD_FAILED,"libnet_build_802_1q %s", libnet_geterror(c));
+    if (libnet_build_802_1q(lpacket->dmac, lpacket->smac, ETHERTYPE_VLAN, 0, 0, vlan_id, proto,
+                NULL, /* payload */
+                0,    /* payload size */
+                c,    /* libnet handle */
+                0) < 0) {
+        SCLogError("libnet_build_802_1q %s", libnet_geterror(c));
         return -1;
     }
     return 0;
@@ -332,7 +328,7 @@ int RejectSendLibnet11IPv4TCP(ThreadVars *tv, Packet *p, void *data, enum Reject
 
     result = libnet_write(c);
     if (result == -1) {
-        SCLogError(SC_ERR_LIBNET_WRITE_FAILED,"libnet_write failed: %s", libnet_geterror(c));
+        SCLogError("libnet_write failed: %s", libnet_geterror(c));
         goto cleanup;
     }
 
@@ -351,7 +347,7 @@ int RejectSendLibnet11IPv4ICMP(ThreadVars *tv, Packet *p, void *data, enum Rejec
     lpacket.id = 0;
     lpacket.flow = 0;
     lpacket.class = 0;
-    const int iplen = IPV4_GET_IPLEN(p);
+    const uint16_t iplen = IPV4_GET_IPLEN(p);
     if (g_reject_dev_mtu >= ETHERNET_HEADER_LEN + LIBNET_IPV4_H + 8) {
         lpacket.len = MIN(g_reject_dev_mtu - ETHERNET_HEADER_LEN, (LIBNET_IPV4_H + iplen));
     } else {
@@ -388,7 +384,7 @@ int RejectSendLibnet11IPv4ICMP(ThreadVars *tv, Packet *p, void *data, enum Rejec
                     c,                        /* libnet context */
                     0)) < 0)                  /* libnet ptag */
     {
-        SCLogError(SC_ERR_LIBNET_BUILD_FAILED,"libnet_build_icmpv4_unreach %s", libnet_geterror(c));
+        SCLogError("libnet_build_icmpv4_unreach %s", libnet_geterror(c));
         goto cleanup;
     }
 
@@ -409,7 +405,7 @@ int RejectSendLibnet11IPv4ICMP(ThreadVars *tv, Packet *p, void *data, enum Rejec
 
     result = libnet_write(c);
     if (result == -1) {
-        SCLogError(SC_ERR_LIBNET_WRITE_FAILED,"libnet_write_raw_ipv4 failed: %s", libnet_geterror(c));
+        SCLogError("libnet_write_raw_ipv4 failed: %s", libnet_geterror(c));
         goto cleanup;
     }
 
@@ -436,7 +432,7 @@ int RejectSendLibnet11IPv6TCP(ThreadVars *tv, Packet *p, void *data, enum Reject
     if (c == NULL)
         return 1;
 
-    lpacket.len = LIBNET_IPV6_H + LIBNET_TCP_H;
+    lpacket.len = LIBNET_TCP_H;
     lpacket.dsize = p->payload_len;
 
     switch (dir) {
@@ -457,7 +453,7 @@ int RejectSendLibnet11IPv6TCP(ThreadVars *tv, Packet *p, void *data, enum Reject
 
     BuildTCP(c, &lpacket);
 
-    if (BuildIPv6(c, &lpacket, IPPROTO_ICMP) < 0)
+    if (BuildIPv6(c, &lpacket, IPPROTO_TCP) < 0)
         goto cleanup;
 
     if (t_inject_mode == LIBNET_LINK) {
@@ -473,7 +469,7 @@ int RejectSendLibnet11IPv6TCP(ThreadVars *tv, Packet *p, void *data, enum Reject
 
     result = libnet_write(c);
     if (result == -1) {
-        SCLogError(SC_ERR_LIBNET_WRITE_FAILED,"libnet_write failed: %s", libnet_geterror(c));
+        SCLogError("libnet_write failed: %s", libnet_geterror(c));
         goto cleanup;
     }
 
@@ -493,7 +489,7 @@ int RejectSendLibnet11IPv6ICMP(ThreadVars *tv, Packet *p, void *data, enum Rejec
     lpacket.id = 0;
     lpacket.flow = 0;
     lpacket.class = 0;
-    const int iplen = IPV6_GET_PLEN(p);
+    const uint16_t iplen = IPV6_GET_PLEN(p);
     if (g_reject_dev_mtu >= ETHERNET_HEADER_LEN + IPV6_HEADER_LEN + 8) {
         lpacket.len = IPV6_HEADER_LEN + MIN(g_reject_dev_mtu - ETHERNET_HEADER_LEN, iplen);
     } else {
@@ -530,7 +526,7 @@ int RejectSendLibnet11IPv6ICMP(ThreadVars *tv, Packet *p, void *data, enum Rejec
                     c,                        /* libnet context */
                     0)) < 0)                  /* libnet ptag */
     {
-        SCLogError(SC_ERR_LIBNET_BUILD_FAILED,"libnet_build_icmpv6_unreach %s", libnet_geterror(c));
+        SCLogError("libnet_build_icmpv6_unreach %s", libnet_geterror(c));
         goto cleanup;
     }
 
@@ -550,7 +546,7 @@ int RejectSendLibnet11IPv6ICMP(ThreadVars *tv, Packet *p, void *data, enum Rejec
 
     result = libnet_write(c);
     if (result == -1) {
-        SCLogError(SC_ERR_LIBNET_WRITE_FAILED,"libnet_write_raw_ipv6 failed: %s", libnet_geterror(c));
+        SCLogError("libnet_write_raw_ipv6 failed: %s", libnet_geterror(c));
         goto cleanup;
     }
 
@@ -563,9 +559,9 @@ cleanup:
 
 int RejectSendLibnet11IPv6ICMP(ThreadVars *tv, Packet *p, void *data, enum RejectDirection dir)
 {
-    SCLogError(SC_ERR_LIBNET_NOT_ENABLED, "Libnet ICMPv6 based rejects are disabled."
-                "Usually this means that you don't have a patched libnet installed,"
-                " or configure couldn't find it.");
+    SCLogError("Libnet ICMPv6 based rejects are disabled."
+               "Usually this means that you don't have a patched libnet installed,"
+               " or configure couldn't find it.");
     return 0;
 }
 #endif /* HAVE_LIBNET_ICMPV6_UNREACH */
@@ -575,33 +571,33 @@ int RejectSendLibnet11IPv6ICMP(ThreadVars *tv, Packet *p, void *data, enum Rejec
 
 int RejectSendLibnet11IPv4TCP(ThreadVars *tv, Packet *p, void *data, enum RejectDirection dir)
 {
-    SCLogError(SC_ERR_LIBNET_NOT_ENABLED, "Libnet based rejects are disabled."
-                "Usually this means that you don't have libnet installed,"
-                " or configure couldn't find it.");
+    SCLogError("Libnet based rejects are disabled."
+               "Usually this means that you don't have libnet installed,"
+               " or configure couldn't find it.");
     return 0;
 }
 
 int RejectSendLibnet11IPv4ICMP(ThreadVars *tv, Packet *p, void *data, enum RejectDirection dir)
 {
-    SCLogError(SC_ERR_LIBNET_NOT_ENABLED, "Libnet based rejects are disabled."
-                "Usually this means that you don't have libnet installed,"
-                " or configure couldn't find it.");
+    SCLogError("Libnet based rejects are disabled."
+               "Usually this means that you don't have libnet installed,"
+               " or configure couldn't find it.");
     return 0;
 }
 
 int RejectSendLibnet11IPv6TCP(ThreadVars *tv, Packet *p, void *data, enum RejectDirection dir)
 {
-    SCLogError(SC_ERR_LIBNET_NOT_ENABLED, "Libnet based rejects are disabled."
-                "Usually this means that you don't have libnet installed,"
-                " or configure couldn't find it.");
+    SCLogError("Libnet based rejects are disabled."
+               "Usually this means that you don't have libnet installed,"
+               " or configure couldn't find it.");
     return 0;
 }
 
 int RejectSendLibnet11IPv6ICMP(ThreadVars *tv, Packet *p, void *data, enum RejectDirection dir)
 {
-    SCLogError(SC_ERR_LIBNET_NOT_ENABLED, "Libnet based rejects are disabled."
-                "Usually this means that you don't have libnet installed,"
-                " or configure couldn't find it.");
+    SCLogError("Libnet based rejects are disabled."
+               "Usually this means that you don't have libnet installed,"
+               " or configure couldn't find it.");
     return 0;
 }
 
