@@ -120,8 +120,6 @@ typedef struct NFQThreadVars_
 
     char *data; /** Per function and thread data */
     int datalen; /** Length of per function and thread data */
-
-    CaptureStats stats;
 } NFQThreadVars;
 /* shared vars for all for nfq queues and threads */
 static NFQGlobalVars nfq_g;
@@ -777,10 +775,7 @@ TmEcode ReceiveNFQThreadDeinit(ThreadVars *t, void *data)
 
 TmEcode VerdictNFQThreadInit(ThreadVars *tv, const void *initdata, void **data)
 {
-    NFQThreadVars *ntv = (NFQThreadVars *) initdata;
-
-    CaptureStatsSetup(tv, &ntv->stats);
-
+    NFQThreadVars *ntv = (NFQThreadVars *)initdata;
     *data = (void *)ntv;
     return TM_ECODE_OK;
 }
@@ -1191,10 +1186,6 @@ TmEcode NFQSetVerdict(Packet *p)
  */
 TmEcode VerdictNFQ(ThreadVars *tv, Packet *p, void *data)
 {
-    NFQThreadVars *ntv = (NFQThreadVars *)data;
-    /* update counters */
-    CaptureStatsUpdate(tv, &ntv->stats, p);
-
     /* if this is a tunnel packet we check if we are ready to verdict
      * already. */
     if (IS_TUNNEL_PKT(p)) {
