@@ -48,9 +48,6 @@
 #define SC_CLASS_CONF_DEF_CONF_FILEPATH CONFIG_DIR "/classification.config"
 #endif
 
-static pcre *regex = NULL;
-static pcre_extra *regex_study = NULL;
-
 uint32_t SCClassConfClasstypeHashFunc(HashTable *ht, void *data, uint16_t datalen);
 char SCClassConfClasstypeHashCompareFunc(void *data1, uint16_t datalen1,
                                          void *data2, uint16_t datalen2);
@@ -61,38 +58,36 @@ static SCClassConfClasstype *SCClassConfAllocClasstype(uint16_t classtype_id,
         const char *classtype, const char *classtype_desc, int priority);
 static void SCClassConfDeAllocClasstype(SCClassConfClasstype *ct);
 
-void SCClassConfInit(void)
+void SCClassConfInit(DetectEngineCtx *de_ctx)
 {
-    const char *eb = NULL;
-    int eo;
+    int en;
+    PCRE2_SIZE eo;
     int opts = 0;
 
-    regex = pcre_compile(DETECT_CLASSCONFIG_REGEX, opts, &eb, &eo, NULL);
-    if (regex == NULL) {
-        SCLogDebug("Compile of \"%s\" failed at offset %" PRId32 ": %s",
-                   DETECT_CLASSCONFIG_REGEX, eo, eb);
-        return;
-    }
-
-    regex_study = pcre_study(regex, 0, &eb);
-    if (eb != NULL) {
-        pcre_free(regex);
-        regex = NULL;
-        SCLogDebug("pcre study failed: %s", eb);
+    de_ctx->class_conf_regex = pcre2_compile(
+            (PCRE2_SPTR8)DETECT_CLASSCONFIG_REGEX, PCRE2_ZERO_TERMINATED, opts, &en, &eo, NULL);
+    if (de_ctx->class_conf_regex == NULL) {
+        PCRE2_UCHAR errbuffer[256];
+        pcre2_get_error_message(en, errbuffer, sizeof(errbuffer));
+        SCLogWarning("pcre2 compile of \"%s\" failed at "
+                     "offset %d: %s",
+                DETECT_CLASSCONFIG_REGEX, (int)eo, errbuffer);
         return;
     }
+    de_ctx->class_conf_regex_match =
+            pcre2_match_data_create_from_pattern(de_ctx->class_conf_regex, NULL);
     return;
 }
 
-void SCClassConfDeinit(void)
+void SCClassConfDeinit(DetectEngineCtx *de_ctx)
 {
-    if (regex != NULL) {
-        pcre_free(regex);
-        regex = NULL;
+    if (de_ctx->class_conf_regex != NULL) {
+        pcre2_code_free(de_ctx->class_conf_regex);
+        de_ctx->class_conf_regex = NULL;
     }
-    if (regex_study != NULL) {
-        pcre_free(regex_study);
-        regex_study = NULL;
+    if (de_ctx->class_conf_regex_match != NULL) {
+        pcre2_match_data_free(de_ctx->class_conf_regex_match);
+        de_ctx->class_conf_regex_match = NULL;
     }
 }
 
@@ -121,7 +116,7 @@ static FILE *SCClassConfInitContextAndLocalResources(DetectEngineCtx *de_ctx, FI
                                           SCClassConfClasstypeHashCompareFunc,
                                           SCClassConfClasstypeHashFree);
     if (de_ctx->class_conf_ht == NULL) {
-        SCLogError(SC_ERR_HASH_TABLE_INIT, "Error initializing the hash "
+        SCLogError("Error initializing the hash "
                    "table");
         return NULL;
     }
@@ -137,8 +132,7 @@ static FILE *SCClassConfInitContextAndLocalResources(DetectEngineCtx *de_ctx, FI
             if (RunmodeIsUnittests())
                 return NULL; // silently fail
 #endif
-            SCLogWarning(SC_ERR_FOPEN, "could not open: \"%s\": %s",
-                    filename, strerror(errno));
+            SCLogWarning("could not open: \"%s\": %s", filename, strerror(errno));
             return NULL;
         }
     }
@@ -215,13 +209,13 @@ static char *SCClassConfStringToLowercase(const char *str)
     char *temp_str = NULL;
 
     if ( (new_str = SCStrdup(str)) == NULL) {
-        SCLogError(SC_ERR_MEM_ALLOC, "Error allocating memory");
+        SCLogError("Error allocating memory");
         return NULL;
     }
 
     temp_str = new_str;
     while (*temp_str != '\0') {
-        *temp_str = tolower((unsigned char)*temp_str);
+        *temp_str = u8_tolower((unsigned char)*temp_str);
         temp_str++;
     }
 
@@ -250,35 +244,41 @@ int SCClassConfAddClasstype(DetectEngineCtx *de_ctx, char *rawstr, uint16_t inde
     SCClassConfClasstype *ct_new = NULL;
     SCClassConfClasstype *ct_lookup = NULL;
 
-#define MAX_SUBSTRINGS 30
     int ret = 0;
-    int ov[MAX_SUBSTRINGS];
 
-    ret = pcre_exec(regex, regex_study, rawstr, strlen(rawstr), 0, 0, ov, 30);
+    ret = pcre2_match(de_ctx->class_conf_regex, (PCRE2_SPTR8)rawstr, strlen(rawstr), 0, 0,
+            de_ctx->class_conf_regex_match, NULL);
     if (ret < 0) {
-        SCLogError(SC_ERR_INVALID_SIGNATURE, "Invalid Classtype in "
-                   "classification.config file");
+        SCLogError("Invalid Classtype in "
+                   "classification.config file %s: \"%s\"",
+                SCClassConfGetConfFilename(de_ctx), rawstr);
         goto error;
     }
 
+    size_t copylen = sizeof(ct_name);
     /* retrieve the classtype name */
-    ret = pcre_copy_substring((char *)rawstr, ov, 30, 1, ct_name, sizeof(ct_name));
+    ret = pcre2_substring_copy_bynumber(
+            de_ctx->class_conf_regex_match, 1, (PCRE2_UCHAR8 *)ct_name, &copylen);
     if (ret < 0) {
-        SCLogInfo("pcre_copy_substring() failed");
+        SCLogInfo("pcre2_substring_copy_bynumber() failed");
         goto error;
     }
 
     /* retrieve the classtype description */
-    ret = pcre_copy_substring((char *)rawstr, ov, 30, 2, ct_desc, sizeof(ct_desc));
+    copylen = sizeof(ct_desc);
+    ret = pcre2_substring_copy_bynumber(
+            de_ctx->class_conf_regex_match, 2, (PCRE2_UCHAR8 *)ct_desc, &copylen);
     if (ret < 0) {
-        SCLogInfo("pcre_copy_substring() failed");
+        SCLogInfo("pcre2_substring_copy_bynumber() failed");
         goto error;
     }
 
     /* retrieve the classtype priority */
-    ret = pcre_copy_substring((char *)rawstr, ov, 30, 3, ct_priority_str, sizeof(ct_priority_str));
+    copylen = sizeof(ct_priority_str);
+    ret = pcre2_substring_copy_bynumber(
+            de_ctx->class_conf_regex_match, 3, (PCRE2_UCHAR8 *)ct_priority_str, &copylen);
     if (ret < 0) {
-        SCLogInfo("pcre_copy_substring() failed");
+        SCLogInfo("pcre2_substring_copy_bynumber() failed");
         goto error;
     }
     if (StringParseUint32(&ct_priority, 10, 0, (const char *)ct_priority_str) < 0) {
@@ -345,17 +345,21 @@ static int SCClassConfIsLineBlankOrComment(char *line)
  *
  * \param de_ctx Pointer to the Detection Engine Context.
  */
-static void SCClassConfParseFile(DetectEngineCtx *de_ctx, FILE *fd)
+static bool SCClassConfParseFile(DetectEngineCtx *de_ctx, FILE *fd)
 {
     char line[1024];
     uint16_t i = 1;
+    int errors = 0;
 
     while (fgets(line, sizeof(line), fd) != NULL) {
         if (SCClassConfIsLineBlankOrComment(line))
             continue;
 
-        SCClassConfAddClasstype(de_ctx, line, i);
-        i++;
+        if (SCClassConfAddClasstype(de_ctx, line, i) == -1) {
+            errors++;
+        } else {
+            i++;
+        }
     }
 
 #ifdef UNITTESTS
@@ -363,7 +367,7 @@ static void SCClassConfParseFile(DetectEngineCtx *de_ctx, FILE *fd)
               de_ctx->class_conf_ht->count);
 #endif
 
-    return;
+    return errors == 0;
 }
 
 /**
@@ -392,16 +396,14 @@ static SCClassConfClasstype *SCClassConfAllocClasstype(uint16_t classtype_id,
         return NULL;
     memset(ct, 0, sizeof(SCClassConfClasstype));
 
-    if ( (ct->classtype = SCClassConfStringToLowercase(classtype)) == NULL) {
-        SCLogError(SC_ERR_MEM_ALLOC, "Error allocating memory");
-
+    if ((ct->classtype = SCClassConfStringToLowercase(classtype)) == NULL) {
         SCClassConfDeAllocClasstype(ct);
         return NULL;
     }
 
     if (classtype_desc != NULL &&
         (ct->classtype_desc = SCStrdup(classtype_desc)) == NULL) {
-        SCLogError(SC_ERR_MEM_ALLOC, "Error allocating memory");
+        SCLogError("Error allocating memory");
 
         SCClassConfDeAllocClasstype(ct);
         return NULL;
@@ -453,7 +455,7 @@ uint32_t SCClassConfClasstypeHashFunc(HashTable *ht, void *data, uint16_t datale
     int len = strlen(ct->classtype);
 
     for (i = 0; i < len; i++)
-        hash += tolower((unsigned char)(ct->classtype)[i]);
+        hash += u8_tolower((unsigned char)(ct->classtype)[i]);
 
     hash = hash % ht->array_size;
 
@@ -523,24 +525,30 @@ void SCClassConfClasstypeHashFree(void *ch)
  * \param de_ctx Pointer to the Detection Engine Context that should be updated
  *               with Classtype information.
  */
-void SCClassConfLoadClassficationConfigFile(DetectEngineCtx *de_ctx, FILE *fd)
+bool SCClassConfLoadClassificationConfigFile(DetectEngineCtx *de_ctx, FILE *fd)
 {
     fd = SCClassConfInitContextAndLocalResources(de_ctx, fd);
     if (fd == NULL) {
 #ifdef UNITTESTS
-        if (RunmodeIsUnittests() && fd == NULL) {
-            return;
+        if (RunmodeIsUnittests()) {
+            return false;
         }
 #endif
-        SCLogError(SC_ERR_OPENING_FILE, "please check the \"classification-file\" "
-                "option in your suricata.yaml file");
-        return;
+        SCLogError("please check the \"classification-file\" "
+                   "option in your suricata.yaml file");
+        return false;
+    }
+
+    bool ret = true;
+    if (!SCClassConfParseFile(de_ctx, fd)) {
+        SCLogWarning("Error loading classification configuration from %s",
+                SCClassConfGetConfFilename(de_ctx));
+        ret = false;
     }
 
-    SCClassConfParseFile(de_ctx, fd);
     SCClassConfDeInitLocalResources(de_ctx, fd);
 
-    return;
+    return ret;
 }
 
 /**
@@ -560,7 +568,7 @@ SCClassConfClasstype *SCClassConfGetClasstype(const char *ct_name,
     char name[strlen(ct_name) + 1];
     size_t s;
     for (s = 0; s < strlen(ct_name); s++)
-        name[s] = tolower((unsigned char)ct_name[s]);
+        name[s] = u8_tolower((unsigned char)ct_name[s]);
     name[s] = '\0';
 
     SCClassConfClasstype ct_lookup = {0, 0, name, NULL };
@@ -589,7 +597,7 @@ FILE *SCClassConfGenerateValidDummyClassConfigFD01(void)
 
     FILE *fd = SCFmemopen((void *)buffer, strlen(buffer), "r");
     if (fd == NULL)
-        SCLogDebug("Error with SCFmemopen() called by Classifiation Config test code");
+        SCLogDebug("Error with SCFmemopen() called by Classification Config test code");
 
     return fd;
 }
@@ -600,7 +608,7 @@ FILE *SCClassConfGenerateValidDummyClassConfigFD01(void)
  *
  * \file_path Pointer to the file_path for the dummy classification file.
  */
-FILE *SCClassConfGenerateInValidDummyClassConfigFD02(void)
+FILE *SCClassConfGenerateInvalidDummyClassConfigFD02(void)
 {
     const char *buffer =
         "config classification: not-suspicious,Not Suspicious Traffic,3\n"
@@ -613,7 +621,7 @@ FILE *SCClassConfGenerateInValidDummyClassConfigFD02(void)
 
     FILE *fd = SCFmemopen((void *)buffer, strlen(buffer), "r");
     if (fd == NULL)
-        SCLogDebug("Error with SCFmemopen() called by Classifiation Config test code");
+        SCLogDebug("Error with SCFmemopen() called by Classification Config test code");
 
     return fd;
 }
@@ -624,7 +632,7 @@ FILE *SCClassConfGenerateInValidDummyClassConfigFD02(void)
  *
  * \file_path Pointer to the file_path for the dummy classification file.
  */
-FILE *SCClassConfGenerateInValidDummyClassConfigFD03(void)
+FILE *SCClassConfGenerateInvalidDummyClassConfigFD03(void)
 {
     const char *buffer =
         "conig classification: not-suspicious,Not Suspicious Traffic,3\n"
@@ -634,7 +642,7 @@ FILE *SCClassConfGenerateInValidDummyClassConfigFD03(void)
 
     FILE *fd = SCFmemopen((void *)buffer, strlen(buffer), "r");
     if (fd == NULL)
-        SCLogDebug("Error with SCFmemopen() called by Classifiation Config test code");
+        SCLogDebug("Error with SCFmemopen() called by Classification Config test code");
 
     return fd;
 }
@@ -652,7 +660,7 @@ static int SCClassConfTest01(void)
         return result;
 
     FILE *fd = SCClassConfGenerateValidDummyClassConfigFD01();
-    SCClassConfLoadClassficationConfigFile(de_ctx, fd);
+    SCClassConfLoadClassificationConfigFile(de_ctx, fd);
 
     if (de_ctx->class_conf_ht == NULL)
         return result;
@@ -677,8 +685,8 @@ static int SCClassConfTest02(void)
     if (de_ctx == NULL)
         return result;
 
-    FILE *fd = SCClassConfGenerateInValidDummyClassConfigFD03();
-    SCClassConfLoadClassficationConfigFile(de_ctx, fd);
+    FILE *fd = SCClassConfGenerateInvalidDummyClassConfigFD03();
+    SCClassConfLoadClassificationConfigFile(de_ctx, fd);
 
     if (de_ctx->class_conf_ht == NULL)
         return result;
@@ -692,27 +700,20 @@ static int SCClassConfTest02(void)
 
 /**
  * \test Check that only valid classtypes are loaded into the hash table from
- *       the classfication.config file.
+ *       the classification.config file.
  */
 static int SCClassConfTest03(void)
 {
     DetectEngineCtx *de_ctx = DetectEngineCtxInit();
-    int result = 0;
 
-    if (de_ctx == NULL)
-        return result;
+    FAIL_IF_NULL(de_ctx);
 
-    FILE *fd = SCClassConfGenerateInValidDummyClassConfigFD02();
-    SCClassConfLoadClassficationConfigFile(de_ctx, fd);
-
-    if (de_ctx->class_conf_ht == NULL)
-        return result;
-
-    result = (de_ctx->class_conf_ht->count == 3);
+    FILE *fd = SCClassConfGenerateInvalidDummyClassConfigFD02();
+    FAIL_IF(SCClassConfLoadClassificationConfigFile(de_ctx, fd));
 
     DetectEngineCtxFree(de_ctx);
 
-    return result;
+    PASS;
 }
 
 /**
@@ -728,7 +729,7 @@ static int SCClassConfTest04(void)
         return 0;
 
     FILE *fd = SCClassConfGenerateValidDummyClassConfigFD01();
-    SCClassConfLoadClassficationConfigFile(de_ctx, fd);
+    SCClassConfLoadClassificationConfigFile(de_ctx, fd);
 
     if (de_ctx->class_conf_ht == NULL)
         return 0;
@@ -760,8 +761,8 @@ static int SCClassConfTest05(void)
     if (de_ctx == NULL)
         return 0;
 
-    FILE *fd = SCClassConfGenerateInValidDummyClassConfigFD03();
-    SCClassConfLoadClassficationConfigFile(de_ctx, fd);
+    FILE *fd = SCClassConfGenerateInvalidDummyClassConfigFD03();
+    SCClassConfLoadClassificationConfigFile(de_ctx, fd);
 
     if (de_ctx->class_conf_ht == NULL)
         return 0;
@@ -780,38 +781,6 @@ static int SCClassConfTest05(void)
     return result;
 }
 
-/**
- * \test Check if the classtype info from the classification.config file have
- *       been loaded into the hash table.
- */
-static int SCClassConfTest06(void)
-{
-    DetectEngineCtx *de_ctx = DetectEngineCtxInit();
-    int result = 1;
-
-    if (de_ctx == NULL)
-        return 0;
-
-    FILE *fd = SCClassConfGenerateInValidDummyClassConfigFD02();
-    SCClassConfLoadClassficationConfigFile(de_ctx, fd);
-
-    if (de_ctx->class_conf_ht == NULL)
-        return 0;
-
-    result = (de_ctx->class_conf_ht->count == 3);
-
-    result &= (SCClassConfGetClasstype("unknown", de_ctx) == NULL);
-    result &= (SCClassConfGetClasstype("not-suspicious", de_ctx) != NULL);
-    result &= (SCClassConfGetClasstype("bamboola1", de_ctx) != NULL);
-    result &= (SCClassConfGetClasstype("bamboola1", de_ctx) != NULL);
-    result &= (SCClassConfGetClasstype("BAMBOolA1", de_ctx) != NULL);
-    result &= (SCClassConfGetClasstype("unkNOwn", de_ctx) == NULL);
-
-    DetectEngineCtxFree(de_ctx);
-
-    return result;
-}
-
 /**
  * \brief This function registers unit tests for Classification Config API.
  */
@@ -822,6 +791,5 @@ void SCClassConfRegisterTests(void)
     UtRegisterTest("SCClassConfTest03", SCClassConfTest03);
     UtRegisterTest("SCClassConfTest04", SCClassConfTest04);
     UtRegisterTest("SCClassConfTest05", SCClassConfTest05);
-    UtRegisterTest("SCClassConfTest06", SCClassConfTest06);
 }
 #endif /* UNITTESTS */
