@@ -35,7 +35,7 @@
 
 #ifdef HAVE_DPDK
 
-void iceDeviceSetRSSHashFunction(uint64_t *rss_hf)
+static void iceDeviceSetRSSHashFunction(uint64_t *rss_hf)
 {
 #if RTE_VERSION < RTE_VERSION_NUM(20, 0, 0, 0)
     *rss_hf = RTE_ETH_RSS_FRAG_IPV4 | RTE_ETH_RSS_NONFRAG_IPV4_OTHER | RTE_ETH_RSS_FRAG_IPV6 |
@@ -46,6 +46,12 @@ void iceDeviceSetRSSHashFunction(uint64_t *rss_hf)
 #endif
 }
 
+void iceDeviceSetRSSConf(struct rte_eth_rss_conf *rss_conf)
+{
+    iceDeviceSetRSSHashFunction(&rss_conf->rss_hf);
+    rss_conf->rss_key_len = 52;
+}
+
 #endif /* HAVE_DPDK */
 /**
  * @}
