@@ -27,6 +27,7 @@
 #include "suricata-common.h"
 #include "util-ip.h"
 #include "util-byte.h"
+#include "util-debug.h"
 
 /** \brief determine if a string is a valid ipv4 address
  *  \retval bool is addr valid?
@@ -134,8 +135,7 @@ struct in_addr *ValidateIPV4Address(const char *addr_str)
         return NULL;
 
     if ( (addr = SCMalloc(sizeof(struct in_addr))) == NULL) {
-        FatalError(SC_ERR_FATAL,
-                   "Fatal error encountered in ValidateIPV4Address. Exiting...");
+        FatalError("Fatal error encountered in ValidateIPV4Address. Exiting...");
     }
 
     if (inet_pton(AF_INET, addr_str, addr) <= 0) {
@@ -148,7 +148,7 @@ struct in_addr *ValidateIPV4Address(const char *addr_str)
 
 /**
  * \brief Validates an IPV6 address and returns the network endian arranged
- *        version of the IPV6 addresss
+ *        version of the IPV6 address
  *
  * \param addr Pointer to a character string containing an IPV6 address
  *
@@ -164,8 +164,7 @@ struct in6_addr *ValidateIPV6Address(const char *addr_str)
         return NULL;
 
     if ( (addr = SCMalloc(sizeof(struct in6_addr))) == NULL) {
-        FatalError(SC_ERR_FATAL,
-                   "Fatal error encountered in ValidateIPV6Address. Exiting...");
+        FatalError("Fatal error encountered in ValidateIPV6Address. Exiting...");
     }
 
     if (inet_pton(AF_INET6, addr_str, addr) <= 0) {
