@@ -24,7 +24,6 @@
  */
 
 #include "suricata-common.h"
-#include "debug.h"
 #include "detect.h"
 #include "pkt-var.h"
 #include "conf.h"
@@ -47,6 +46,7 @@
 #include "util-proto-name.h"
 #include "util-logopenfile.h"
 #include "util-time.h"
+#include "util-conf.h"
 
 #ifdef HAVE_LUA
 
@@ -56,6 +56,7 @@
 
 #include "util-lua.h"
 #include "util-lua-common.h"
+#include "action-globals.h"
 
 int LuaCallbackError(lua_State *luastate, const char *msg)
 {
@@ -169,10 +170,10 @@ static int LuaCallbackPacketPayload(lua_State *luastate)
  *
  *  Places: seconds (number), microseconds (number)
  */
-static int LuaCallbackTimestampPushToStack(lua_State *luastate, const struct timeval *ts)
+static int LuaCallbackTimestampPushToStack(lua_State *luastate, const SCTime_t ts)
 {
-    lua_pushnumber(luastate, (double)ts->tv_sec);
-    lua_pushnumber(luastate, (double)ts->tv_usec);
+    lua_pushnumber(luastate, (double)SCTIME_SECS(ts));
+    lua_pushnumber(luastate, (double)SCTIME_USECS(ts));
     return 2;
 }
 
@@ -187,7 +188,7 @@ static int LuaCallbackTimestampPushToStack(lua_State *luastate, const struct tim
 static int LuaCallbackTimeStringPushToStackFromPacket(lua_State *luastate, const Packet *p)
 {
     char timebuf[64];
-    CreateTimeString(&p->ts, timebuf, sizeof(timebuf));
+    CreateTimeString(p->ts, timebuf, sizeof(timebuf));
     lua_pushstring (luastate, timebuf);
     return 1;
 }
@@ -202,7 +203,7 @@ static int LuaCallbackPacketTimestamp(lua_State *luastate)
     if (p == NULL)
         return LuaCallbackError(luastate, "internal error: no packet");
 
-    return LuaCallbackTimestampPushToStack(luastate, &p->ts);
+    return LuaCallbackTimestampPushToStack(luastate, p->ts);
 }
 
 /** \internal
@@ -228,14 +229,13 @@ static int LuaCallbackPacketTimeString(lua_State *luastate)
  * Places: seconds (number), seconds (number), microseconds (number),
  *         microseconds (number)
  */
-static int LuaCallbackFlowTimestampsPushToStack(lua_State *luastate,
-                                                const struct timeval *startts,
-                                                const struct timeval *lastts)
+static int LuaCallbackFlowTimestampsPushToStack(
+        lua_State *luastate, const SCTime_t startts, const SCTime_t lastts)
 {
-    lua_pushnumber(luastate, (double)startts->tv_sec);
-    lua_pushnumber(luastate, (double)lastts->tv_sec);
-    lua_pushnumber(luastate, (double)startts->tv_usec);
-    lua_pushnumber(luastate, (double)lastts->tv_usec);
+    lua_pushnumber(luastate, (double)SCTIME_SECS(startts));
+    lua_pushnumber(luastate, (double)SCTIME_SECS(lastts));
+    lua_pushnumber(luastate, (double)SCTIME_USECS(startts));
+    lua_pushnumber(luastate, (double)SCTIME_USECS(lastts));
     return 4;
 }
 
@@ -250,8 +250,7 @@ static int LuaCallbackFlowTimestamps(lua_State *luastate)
         return LuaCallbackError(luastate, "internal error: no flow");
     }
 
-    return LuaCallbackFlowTimestampsPushToStack(luastate, &flow->startts,
-                                                &flow->lastts);
+    return LuaCallbackFlowTimestampsPushToStack(luastate, flow->startts, flow->lastts);
 }
 
 /** \internal
@@ -265,7 +264,7 @@ static int LuaCallbackFlowTimestamps(lua_State *luastate)
 static int LuaCallbackTimeStringPushToStackFromFlow(lua_State *luastate, const Flow *flow)
 {
     char timebuf[64];
-    CreateTimeString(&flow->startts, timebuf, sizeof(timebuf));
+    CreateTimeString(flow->startts, timebuf, sizeof(timebuf));
     lua_pushstring (luastate, timebuf);
     return 1;
 }
@@ -548,87 +547,157 @@ static int LuaCallbackFlowId(lua_State *luastate)
 }
 
 /** \internal
- *  \brief fill lua stack with alert info
+ *  \brief fill lua stack with signature info
  *  \param luastate the lua state
- *  \param pa pointer to packet alert struct
+ *  \param s pointer to signature struct
  *  \retval cnt number of data items placed on the stack
  *
  *  Places: sid (number), rev (number), gid (number)
  */
-static int LuaCallbackRuleIdsPushToStackFromPacketAlert(lua_State *luastate, const PacketAlert *pa)
+static int LuaCallbackRuleIdsPushToStackFromSignature(lua_State *luastate, const Signature *s)
 {
-    lua_pushinteger(luastate, pa->s->id);
-    lua_pushinteger(luastate, pa->s->rev);
-    lua_pushinteger(luastate, pa->s->gid);
+    lua_pushinteger(luastate, s->id);
+    lua_pushinteger(luastate, s->rev);
+    lua_pushinteger(luastate, s->gid);
     return 3;
 }
 
 /** \internal
  *  \brief Wrapper for getting tuple info into a lua script
  *  \retval cnt number of items placed on the stack
+ *
+ *  Info is pulled from PacketAlert if it exists in lua registry (true for logging scripts)
+ *  otherwise pulled from Signature in lua registry (for match scripts)
  */
 static int LuaCallbackRuleIds(lua_State *luastate)
 {
+    const Signature *s = NULL;
     const PacketAlert *pa = LuaStateGetPacketAlert(luastate);
-    if (pa == NULL)
-        return LuaCallbackError(luastate, "internal error: no packet");
-
-    return LuaCallbackRuleIdsPushToStackFromPacketAlert(luastate, pa);
+    if (pa != NULL) {
+        s = pa->s;
+    } else {
+        s = LuaStateGetSignature(luastate);
+        if (s == NULL)
+            return LuaCallbackError(luastate, "internal error: no packet alert or signature");
+    }
+    return LuaCallbackRuleIdsPushToStackFromSignature(luastate, s);
 }
 
 /** \internal
- *  \brief fill lua stack with alert info
+ *  \brief fill lua stack with signature info
  *  \param luastate the lua state
- *  \param pa pointer to packet alert struct
+ *  \param s pointer to signature struct
  *  \retval cnt number of data items placed on the stack
  *
- *  Places: msg (string)
+ *  Places: action (string)
  */
-static int LuaCallbackRuleMsgPushToStackFromPacketAlert(lua_State *luastate, const PacketAlert *pa)
+static int LuaCallbackRuleActionPushToStackFromSignature(lua_State *luastate, const Signature *s)
 {
-    lua_pushstring (luastate, pa->s->msg);
+    const char *action = "";
+    if (s->action & ACTION_PASS) {
+        action = "pass";
+    } else if ((s->action & ACTION_REJECT) || (s->action & ACTION_REJECT_BOTH) ||
+               (s->action & ACTION_REJECT_DST)) {
+        action = "reject";
+    } else if (s->action & ACTION_DROP) {
+        action = "drop";
+    } else if (s->action & ACTION_ALERT) {
+        action = "alert";
+    }
+    lua_pushstring(luastate, action);
     return 1;
 }
 
 /** \internal
  *  \brief Wrapper for getting tuple info into a lua script
  *  \retval cnt number of items placed on the stack
+ *
+ *  Info is pulled from PacketAlert if it exists in lua registry (true for logging scripts)
+ *  otherwise pulled from Signature in lua registry (for match scripts)
  */
-static int LuaCallbackRuleMsg(lua_State *luastate)
+static int LuaCallbackRuleAction(lua_State *luastate)
 {
+    const Signature *s = NULL;
     const PacketAlert *pa = LuaStateGetPacketAlert(luastate);
-    if (pa == NULL)
-        return LuaCallbackError(luastate, "internal error: no packet");
-
-    return LuaCallbackRuleMsgPushToStackFromPacketAlert(luastate, pa);
+    if (pa != NULL) {
+        s = pa->s;
+    } else {
+        s = LuaStateGetSignature(luastate);
+        if (s == NULL)
+            return LuaCallbackError(luastate, "internal error: no packet alert or signature");
+    }
+    return LuaCallbackRuleActionPushToStackFromSignature(luastate, s);
 }
 
 /** \internal
- *  \brief fill lua stack with alert info
+ *  \brief fill lua stack with signature info
  *  \param luastate the lua state
- *  \param pa pointer to packet alert struct
+ *  \param s pointer to signature struct
+ *  \retval cnt number of data items placed on the stack
+ *
+ *  Places: msg (string)
+ */
+static int LuaCallbackRuleMsgPushToStackFromSignature(lua_State *luastate, const Signature *s)
+{
+    lua_pushstring(luastate, s->msg);
+    return 1;
+}
+
+/** \internal
+ *  \brief Wrapper for getting tuple info into a lua script
+ *  \retval cnt number of items placed on the stack
+ *
+ *  Info is pulled from PacketAlert if it exists in lua registry (true for logging scripts)
+ *  otherwise pulled from Signature in lua registry (for match scripts)
+ */
+static int LuaCallbackRuleMsg(lua_State *luastate)
+{
+    const Signature *s = NULL;
+    const PacketAlert *pa = LuaStateGetPacketAlert(luastate);
+    if (pa != NULL) {
+        s = pa->s;
+    } else {
+        s = LuaStateGetSignature(luastate);
+        if (s == NULL)
+            return LuaCallbackError(luastate, "internal error: no packet alert or signature");
+    }
+    return LuaCallbackRuleMsgPushToStackFromSignature(luastate, s);
+}
+
+/** \internal
+ *  \brief fill lua stack with signature info
+ *  \param luastate the lua state
+ *  \param s pointer to signature struct
  *  \retval cnt number of data items placed on the stack
  *
  *  Places: class (string), prio (number)
  */
-static int LuaCallbackRuleClassPushToStackFromPacketAlert(lua_State *luastate, const PacketAlert *pa)
+static int LuaCallbackRuleClassPushToStackFromSignature(lua_State *luastate, const Signature *s)
 {
-    lua_pushstring (luastate, pa->s->class_msg);
-    lua_pushnumber (luastate, pa->s->prio);
+    lua_pushstring(luastate, s->class_msg);
+    lua_pushinteger(luastate, s->prio);
     return 2;
 }
 
 /** \internal
  *  \brief Wrapper for getting tuple info into a lua script
  *  \retval cnt number of items placed on the stack
+ *
+ *  Info is pulled from PacketAlert if it exists in lua registry (true for logging scripts)
+ *  otherwise pulled from Signature in lua registry (for match scripts)
  */
 static int LuaCallbackRuleClass(lua_State *luastate)
 {
+    const Signature *s = NULL;
     const PacketAlert *pa = LuaStateGetPacketAlert(luastate);
-    if (pa == NULL)
-        return LuaCallbackError(luastate, "internal error: no packet");
-
-    return LuaCallbackRuleClassPushToStackFromPacketAlert(luastate, pa);
+    if (pa != NULL) {
+        s = pa->s;
+    } else {
+        s = LuaStateGetSignature(luastate);
+        if (s == NULL)
+            return LuaCallbackError(luastate, "internal error: no packet alert or signature");
+    }
+    return LuaCallbackRuleClassPushToStackFromSignature(luastate, s);
 }
 
 static int LuaCallbackLogPath(lua_State *luastate)
@@ -687,7 +756,7 @@ static int LuaCallbackLogWarning(lua_State *luastate)
     lua_getstack(luastate, 1, &ar);
     lua_getinfo(luastate, "nSl", &ar);
     const char *funcname = ar.name ? ar.name : ar.what;
-    SCLogWarningRaw(SC_WARN_LUA_SCRIPT, ar.short_src, funcname, ar.currentline, "%s", msg);
+    SCLogWarningRaw(ar.short_src, funcname, ar.currentline, "%s", msg);
     return 0;
 }
 
@@ -700,7 +769,7 @@ static int LuaCallbackLogError(lua_State *luastate)
     lua_getstack(luastate, 1, &ar);
     lua_getinfo(luastate, "nSl", &ar);
     const char *funcname = ar.name ? ar.name : ar.what;
-    SCLogErrorRaw(SC_ERR_LUA_SCRIPT, ar.short_src, funcname, ar.currentline, "%s", msg);
+    SCLogErrorRaw(ar.short_src, funcname, ar.currentline, "%s", msg);
     return 0;
 }
 
@@ -716,9 +785,12 @@ static int LuaCallbackLogError(lua_State *luastate)
  */
 static int LuaCallbackFileInfoPushToStackFromFile(lua_State *luastate, const File *file)
 {
-#ifdef HAVE_NSS
+    char *md5ptr = NULL;
+    char *sha1ptr = NULL;
+    char *sha256ptr = NULL;
+
     char md5[33] = "";
-    char *md5ptr = md5;
+    md5ptr = md5;
     if (file->flags & FILE_MD5) {
         size_t x;
         for (x = 0; x < sizeof(file->md5); x++) {
@@ -728,7 +800,7 @@ static int LuaCallbackFileInfoPushToStackFromFile(lua_State *luastate, const Fil
         }
     }
     char sha1[41] = "";
-    char *sha1ptr = sha1;
+    sha1ptr = sha1;
     if (file->flags & FILE_SHA1) {
         size_t x;
         for (x = 0; x < sizeof(file->sha1); x++) {
@@ -738,7 +810,7 @@ static int LuaCallbackFileInfoPushToStackFromFile(lua_State *luastate, const Fil
         }
     }
     char sha256[65] = "";
-    char *sha256ptr = sha256;
+    sha256ptr = sha256;
     if (file->flags & FILE_SHA256) {
         size_t x;
         for (x = 0; x < sizeof(file->sha256); x++) {
@@ -747,14 +819,10 @@ static int LuaCallbackFileInfoPushToStackFromFile(lua_State *luastate, const Fil
             strlcat(sha256, one, sizeof(sha256));
         }
     }
-#else
-    char *md5ptr = NULL;
-    char *sha1ptr = NULL;
-    char *sha256ptr = NULL;
-#endif
 
+    lua_Integer tx_id = LuaStateGetTxId(luastate);
     lua_pushinteger(luastate, file->file_store_id);
-    lua_pushinteger(luastate, file->txid);
+    lua_pushinteger(luastate, tx_id);
     lua_pushlstring(luastate, (char *)file->name, file->name_len);
     lua_pushinteger(luastate, FileTrackedSize(file));
     lua_pushstring (luastate,
@@ -909,6 +977,8 @@ int LuaRegisterFunctions(lua_State *luastate)
 
     lua_pushcfunction(luastate, LuaCallbackRuleIds);
     lua_setglobal(luastate, "SCRuleIds");
+    lua_pushcfunction(luastate, LuaCallbackRuleAction);
+    lua_setglobal(luastate, "SCRuleAction");
     lua_pushcfunction(luastate, LuaCallbackRuleMsg);
     lua_setglobal(luastate, "SCRuleMsg");
     lua_pushcfunction(luastate, LuaCallbackRuleClass);
