@@ -29,6 +29,7 @@
 #ifndef __UTIL_MEMCMP_H__
 #define __UTIL_MEMCMP_H__
 
+#include "suricata-common.h"
 #include "util-optimize.h"
 
 /** \brief compare two patterns, converting the 2nd to lowercase
@@ -297,5 +298,15 @@ static inline int SCMemcmpLowercase(const void *s1, const void *s2, size_t len)
 
 #endif /* SIMD */
 
+static inline int SCBufferCmp(const void *s1, size_t len1, const void *s2, size_t len2)
+{
+    if (len1 == len2) {
+        return SCMemcmp(s1, s2, len1);
+    } else if (len1 < len2) {
+        return -1;
+    }
+    return 1;
+}
+
 #endif /* __UTIL_MEMCMP_H__ */
 
