@@ -24,6 +24,7 @@
 #ifndef __UTIL_MPM_H__
 #define __UTIL_MPM_H__
 
+#include "app-layer-protos.h"
 #include "util-prefilter.h"
 
 #define MPM_INIT_HASH_SIZE 65536
@@ -54,7 +55,7 @@ typedef struct MpmThreadCtx_ {
 typedef struct MpmPattern_ {
     /* length of the pattern */
     uint16_t len;
-    /* flags decribing the pattern */
+    /* flags describing the pattern */
     uint8_t flags;
 
     /* offset into the buffer where match may start */
@@ -67,7 +68,7 @@ typedef struct MpmPattern_ {
     uint8_t *original_pat;
     /* case sensitive */
     uint8_t *cs;
-    /* case INsensitive */
+    /* case insensitive */
     uint8_t *ci;
     /* pattern id */
     uint32_t id;
@@ -112,12 +113,14 @@ typedef struct MpmCtx_ {
  * we should supply this as the key */
 #define MPM_CTX_FACTORY_UNIQUE_CONTEXT -1
 
-typedef struct MpmCtxFactoryItem_ {
+typedef struct MpmCtxFactoryItem {
     const char *name;
     MpmCtx *mpm_ctx_ts;
     MpmCtx *mpm_ctx_tc;
     int32_t id;
     int32_t sm_list;
+    AppProto alproto; /**< ALPROTO_UNKNOWN is not an app item */
+    struct MpmCtxFactoryItem *next;
 } MpmCtxFactoryItem;
 
 typedef struct MpmCtxFactoryContainer_ {
@@ -127,15 +130,11 @@ typedef struct MpmCtxFactoryContainer_ {
 } MpmCtxFactoryContainer;
 
 /** pattern is case insensitive */
-#define MPM_PATTERN_FLAG_NOCASE     0x01
-/** pattern is negated */
-#define MPM_PATTERN_FLAG_NEGATED    0x02
+#define MPM_PATTERN_FLAG_NOCASE 0x01
 /** pattern has a depth setting */
 #define MPM_PATTERN_FLAG_DEPTH      0x04
 /** pattern has an offset setting */
-#define MPM_PATTERN_FLAG_OFFSET     0x08
-/** one byte pattern (used in b2g) */
-#define MPM_PATTERN_ONE_BYTE        0x10
+#define MPM_PATTERN_FLAG_OFFSET 0x08
 /** the ctx uses it's own internal id instead of
  *  what is passed through the API */
 #define MPM_PATTERN_CTX_OWNS_ID     0x20
@@ -169,25 +168,21 @@ typedef struct MpmTableElmt_ {
 } MpmTableElmt;
 
 extern MpmTableElmt mpm_table[MPM_TABLE_SIZE];
-extern int mpm_default_matcher;
+extern uint8_t mpm_default_matcher;
 
 struct DetectEngineCtx_;
 
-int32_t MpmFactoryRegisterMpmCtxProfile(struct DetectEngineCtx_ *, const char *, const int);
+int32_t MpmFactoryRegisterMpmCtxProfile(
+        struct DetectEngineCtx_ *, const char *, const int, const AppProto);
 void MpmFactoryReClaimMpmCtx(const struct DetectEngineCtx_ *, MpmCtx *);
 MpmCtx *MpmFactoryGetMpmCtxForProfile(const struct DetectEngineCtx_ *, int32_t, int);
 void MpmFactoryDeRegisterAllMpmCtxProfiles(struct DetectEngineCtx_ *);
 int32_t MpmFactoryIsMpmCtxAvailable(const struct DetectEngineCtx_ *, const MpmCtx *);
 
-int PmqSetup(PrefilterRuleStore *);
-void PmqReset(PrefilterRuleStore *);
-void PmqCleanup(PrefilterRuleStore *);
-void PmqFree(PrefilterRuleStore *);
-
 void MpmTableSetup(void);
 void MpmRegisterTests(void);
 
-void MpmInitCtx(MpmCtx *mpm_ctx, uint16_t matcher);
+void MpmInitCtx(MpmCtx *mpm_ctx, uint8_t matcher);
 void MpmInitThreadCtx(MpmThreadCtx *mpm_thread_ctx, uint16_t);
 
 int MpmAddPatternCS(struct MpmCtx_ *mpm_ctx, uint8_t *pat, uint16_t patlen,
